'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_framebuffer_object'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_framebuffer_object',error_checker=_errors._error_checker)
GL_COLOR_ATTACHMENT0_EXT=_C('GL_COLOR_ATTACHMENT0_EXT',0x8CE0)
GL_COLOR_ATTACHMENT10_EXT=_C('GL_COLOR_ATTACHMENT10_EXT',0x8CEA)
GL_COLOR_ATTACHMENT11_EXT=_C('GL_COLOR_ATTACHMENT11_EXT',0x8CEB)
GL_COLOR_ATTACHMENT12_EXT=_C('GL_COLOR_ATTACHMENT12_EXT',0x8CEC)
GL_COLOR_ATTACHMENT13_EXT=_C('GL_COLOR_ATTACHMENT13_EXT',0x8CED)
GL_COLOR_ATTACHMENT14_EXT=_C('GL_COLOR_ATTACHMENT14_EXT',0x8CEE)
GL_COLOR_ATTACHMENT15_EXT=_C('GL_COLOR_ATTACHMENT15_EXT',0x8CEF)
GL_COLOR_ATTACHMENT1_EXT=_C('GL_COLOR_ATTACHMENT1_EXT',0x8CE1)
GL_COLOR_ATTACHMENT2_EXT=_C('GL_COLOR_ATTACHMENT2_EXT',0x8CE2)
GL_COLOR_ATTACHMENT3_EXT=_C('GL_COLOR_ATTACHMENT3_EXT',0x8CE3)
GL_COLOR_ATTACHMENT4_EXT=_C('GL_COLOR_ATTACHMENT4_EXT',0x8CE4)
GL_COLOR_ATTACHMENT5_EXT=_C('GL_COLOR_ATTACHMENT5_EXT',0x8CE5)
GL_COLOR_ATTACHMENT6_EXT=_C('GL_COLOR_ATTACHMENT6_EXT',0x8CE6)
GL_COLOR_ATTACHMENT7_EXT=_C('GL_COLOR_ATTACHMENT7_EXT',0x8CE7)
GL_COLOR_ATTACHMENT8_EXT=_C('GL_COLOR_ATTACHMENT8_EXT',0x8CE8)
GL_COLOR_ATTACHMENT9_EXT=_C('GL_COLOR_ATTACHMENT9_EXT',0x8CE9)
GL_DEPTH_ATTACHMENT_EXT=_C('GL_DEPTH_ATTACHMENT_EXT',0x8D00)
GL_FRAMEBUFFER_ATTACHMENT_OBJECT_NAME_EXT=_C('GL_FRAMEBUFFER_ATTACHMENT_OBJECT_NAME_EXT',0x8CD1)
GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE_EXT=_C('GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE_EXT',0x8CD0)
GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_3D_ZOFFSET_EXT=_C('GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_3D_ZOFFSET_EXT',0x8CD4)
GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE_EXT=_C('GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE_EXT',0x8CD3)
GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL_EXT=_C('GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL_EXT',0x8CD2)
GL_FRAMEBUFFER_BINDING_EXT=_C('GL_FRAMEBUFFER_BINDING_EXT',0x8CA6)
GL_FRAMEBUFFER_COMPLETE_EXT=_C('GL_FRAMEBUFFER_COMPLETE_EXT',0x8CD5)
GL_FRAMEBUFFER_EXT=_C('GL_FRAMEBUFFER_EXT',0x8D40)
GL_FRAMEBUFFER_INCOMPLETE_ATTACHMENT_EXT=_C('GL_FRAMEBUFFER_INCOMPLETE_ATTACHMENT_EXT',0x8CD6)
GL_FRAMEBUFFER_INCOMPLETE_DIMENSIONS_EXT=_C('GL_FRAMEBUFFER_INCOMPLETE_DIMENSIONS_EXT',0x8CD9)
GL_FRAMEBUFFER_INCOMPLETE_DRAW_BUFFER_EXT=_C('GL_FRAMEBUFFER_INCOMPLETE_DRAW_BUFFER_EXT',0x8CDB)
GL_FRAMEBUFFER_INCOMPLETE_FORMATS_EXT=_C('GL_FRAMEBUFFER_INCOMPLETE_FORMATS_EXT',0x8CDA)
GL_FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT_EXT=_C('GL_FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT_EXT',0x8CD7)
GL_FRAMEBUFFER_INCOMPLETE_READ_BUFFER_EXT=_C('GL_FRAMEBUFFER_INCOMPLETE_READ_BUFFER_EXT',0x8CDC)
GL_FRAMEBUFFER_UNSUPPORTED_EXT=_C('GL_FRAMEBUFFER_UNSUPPORTED_EXT',0x8CDD)
GL_INVALID_FRAMEBUFFER_OPERATION_EXT=_C('GL_INVALID_FRAMEBUFFER_OPERATION_EXT',0x0506)
GL_MAX_COLOR_ATTACHMENTS_EXT=_C('GL_MAX_COLOR_ATTACHMENTS_EXT',0x8CDF)
GL_MAX_RENDERBUFFER_SIZE_EXT=_C('GL_MAX_RENDERBUFFER_SIZE_EXT',0x84E8)
GL_RENDERBUFFER_ALPHA_SIZE_EXT=_C('GL_RENDERBUFFER_ALPHA_SIZE_EXT',0x8D53)
GL_RENDERBUFFER_BINDING_EXT=_C('GL_RENDERBUFFER_BINDING_EXT',0x8CA7)
GL_RENDERBUFFER_BLUE_SIZE_EXT=_C('GL_RENDERBUFFER_BLUE_SIZE_EXT',0x8D52)
GL_RENDERBUFFER_DEPTH_SIZE_EXT=_C('GL_RENDERBUFFER_DEPTH_SIZE_EXT',0x8D54)
GL_RENDERBUFFER_EXT=_C('GL_RENDERBUFFER_EXT',0x8D41)
GL_RENDERBUFFER_GREEN_SIZE_EXT=_C('GL_RENDERBUFFER_GREEN_SIZE_EXT',0x8D51)
GL_RENDERBUFFER_HEIGHT_EXT=_C('GL_RENDERBUFFER_HEIGHT_EXT',0x8D43)
GL_RENDERBUFFER_INTERNAL_FORMAT_EXT=_C('GL_RENDERBUFFER_INTERNAL_FORMAT_EXT',0x8D44)
GL_RENDERBUFFER_RED_SIZE_EXT=_C('GL_RENDERBUFFER_RED_SIZE_EXT',0x8D50)
GL_RENDERBUFFER_STENCIL_SIZE_EXT=_C('GL_RENDERBUFFER_STENCIL_SIZE_EXT',0x8D55)
GL_RENDERBUFFER_WIDTH_EXT=_C('GL_RENDERBUFFER_WIDTH_EXT',0x8D42)
GL_STENCIL_ATTACHMENT_EXT=_C('GL_STENCIL_ATTACHMENT_EXT',0x8D20)
GL_STENCIL_INDEX16_EXT=_C('GL_STENCIL_INDEX16_EXT',0x8D49)
GL_STENCIL_INDEX1_EXT=_C('GL_STENCIL_INDEX1_EXT',0x8D46)
GL_STENCIL_INDEX4_EXT=_C('GL_STENCIL_INDEX4_EXT',0x8D47)
GL_STENCIL_INDEX8_EXT=_C('GL_STENCIL_INDEX8_EXT',0x8D48)
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glBindFramebufferEXT(target,framebuffer):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glBindRenderbufferEXT(target,renderbuffer):pass
@_f
@_p.types(_cs.GLenum,_cs.GLenum)
def glCheckFramebufferStatusEXT(target):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glDeleteFramebuffersEXT(n,framebuffers):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glDeleteRenderbuffersEXT(n,renderbuffers):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum,_cs.GLuint)
def glFramebufferRenderbufferEXT(target,attachment,renderbuffertarget,renderbuffer):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum,_cs.GLuint,_cs.GLint)
def glFramebufferTexture1DEXT(target,attachment,textarget,texture,level):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum,_cs.GLuint,_cs.GLint)
def glFramebufferTexture2DEXT(target,attachment,textarget,texture,level):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum,_cs.GLuint,_cs.GLint,_cs.GLint)
def glFramebufferTexture3DEXT(target,attachment,textarget,texture,level,zoffset):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glGenFramebuffersEXT(n,framebuffers):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glGenRenderbuffersEXT(n,renderbuffers):pass
@_f
@_p.types(None,_cs.GLenum)
def glGenerateMipmapEXT(target):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetFramebufferAttachmentParameterivEXT(target,attachment,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetRenderbufferParameterivEXT(target,pname,params):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLuint)
def glIsFramebufferEXT(framebuffer):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLuint)
def glIsRenderbufferEXT(renderbuffer):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLsizei,_cs.GLsizei)
def glRenderbufferStorageEXT(target,internalformat,width,height):pass



'''OpenGL extension AMD.vertex_shader_viewport_index

This module customises the behaviour of the 
OpenGL.raw.GL.AMD.vertex_shader_viewport_index to provide a more 
Python-friendly API

Overview (from the spec)
	
	The gl_ViewportIndex built-in variable was introduced by the
	ARB_viewport_array extension and OpenGL 4.1. This variable is available
	in un-extended OpenGL only to the geometry shader. When written in the
	geometry shader, it causes geometry to be directed to one of an array
	of several independent viewport rectangles.
	
	In order to use any viewport other than zero, a geometry shader must be
	present. Geometry shaders introduce processing overhead and potential
	performance issues. This extension exposes the gl_ViewportIndex built-in
	variable to the vertex shader, allowing the functionality introduced by
	ARB_viewport_array to be accessed without requiring a geometry shader to
	be present.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/AMD/vertex_shader_viewport_index.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.AMD.vertex_shader_viewport_index import *
from OpenGL.raw.GL.AMD.vertex_shader_viewport_index import _EXTENSION_NAME

def glInitVertexShaderViewportIndexAMD():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension NV.fragment_program

This module customises the behaviour of the 
OpenGL.raw.GL.NV.fragment_program to provide a more 
Python-friendly API

Overview (from the spec)
	
	OpenGL mandates a certain set of configurable per-fragment computations
	defining texture lookup, texture environment, color sum, and fog
	operations.  Each of these areas provide a useful but limited set of fixed
	operations.  For example, unextended OpenGL 1.2.1 provides only four
	texture environment modes, color sum, and three fog modes.  Many OpenGL
	extensions have either improved existing functionality or introduced new
	configurable fragment operations.  While these extensions have enabled new
	and interesting rendering effects, the set of effects is limited by the
	set of special modes introduced by the extension.  This lack of
	flexibility is in contrast to the high-level of programmability of
	general-purpose CPUs and other (frequently software-based) shading
	languages.  The purpose of this extension is to expose to the OpenGL
	application writer an unprecedented degree of programmability in the
	computation of final fragment colors and depth values.
	
	This extension provides a mechanism for defining fragment program
	instruction sequences for application-defined fragment programs.  When in
	fragment program mode, a program is executed each time a fragment is
	produced by rasterization.  The inputs for the program are the attributes
	(position, colors, texture coordinates) associated with the fragment and a
	set of constant registers.  A fragment program can perform mathematical
	computations and texture lookups using arbitrary texture coordinates.  The
	results of a fragment program are new color and depth values for the
	fragment.
	
	This extension defines a programming model including a 4-component vector
	instruction set, 16- and 32-bit floating-point data types, and a
	relatively large set of temporary registers.  The programming model also
	includes a condition code vector which can be used to mask register writes
	at run-time or kill fragments altogether.  The syntax, program
	instructions, and general semantics are similar to those in the
	NV_vertex_program and NV_vertex_program2 extensions, which provide for the
	execution of an arbitrary program each time the GL receives a vertex.
	
	The fragment program execution environment is designed for efficient
	hardware implementation and to support a wide variety of programs.  By
	design, the entire set of existing fragment programs defined by existing
	OpenGL per-fragment computation extensions can be implemented using the
	extension's programming model.
	
	The fragment program execution environment accesses textures via
	arbitrarily computed texture coordinates.  As such, there is no necessary
	correspondence between the texture coordinates and texture maps previously
	lumped into a single "texture unit".  This extension separates the notion
	of "texture coordinate sets" and "texture image units" (texture maps and
	associated parameters), allowing implementations with a different number
	of each.  The initial implementation of this extension will support 8
	texture coordinate sets and 16 texture image units.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/fragment_program.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.fragment_program import *
from OpenGL.raw.GL.NV.fragment_program import _EXTENSION_NAME

def glInitFragmentProgramNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

glProgramNamedParameter4fNV=wrapper.wrapper(glProgramNamedParameter4fNV).setInputArraySize(
    'name', 1
)
glProgramNamedParameter4fvNV=wrapper.wrapper(glProgramNamedParameter4fvNV).setInputArraySize(
    'name', 1
).setInputArraySize(
    'v', 4
)
glProgramNamedParameter4dNV=wrapper.wrapper(glProgramNamedParameter4dNV).setInputArraySize(
    'name', 1
)
glProgramNamedParameter4dvNV=wrapper.wrapper(glProgramNamedParameter4dvNV).setInputArraySize(
    'name', 1
).setInputArraySize(
    'v', 4
)
glGetProgramNamedParameterfvNV=wrapper.wrapper(glGetProgramNamedParameterfvNV).setInputArraySize(
    'name', 1
).setOutput(
    'params',size=(4,),orPassIn=True
)
glGetProgramNamedParameterdvNV=wrapper.wrapper(glGetProgramNamedParameterdvNV).setInputArraySize(
    'name', 1
).setOutput(
    'params',size=(4,),orPassIn=True
)
### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_VERSION_GL_1_5'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_VERSION_GL_1_5',error_checker=_errors._error_checker)
GL_ARRAY_BUFFER=_C('GL_ARRAY_BUFFER',0x8892)
GL_ARRAY_BUFFER_BINDING=_C('GL_ARRAY_BUFFER_BINDING',0x8894)
GL_BUFFER_ACCESS=_C('GL_BUFFER_ACCESS',0x88BB)
GL_BUFFER_MAPPED=_C('GL_BUFFER_MAPPED',0x88BC)
GL_BUFFER_MAP_POINTER=_C('GL_BUFFER_MAP_POINTER',0x88BD)
GL_BUFFER_SIZE=_C('GL_BUFFER_SIZE',0x8764)
GL_BUFFER_USAGE=_C('GL_BUFFER_USAGE',0x8765)
GL_COLOR_ARRAY_BUFFER_BINDING=_C('GL_COLOR_ARRAY_BUFFER_BINDING',0x8898)
GL_CURRENT_FOG_COORD=_C('GL_CURRENT_FOG_COORD',0x8453)
GL_CURRENT_QUERY=_C('GL_CURRENT_QUERY',0x8865)
GL_DYNAMIC_COPY=_C('GL_DYNAMIC_COPY',0x88EA)
GL_DYNAMIC_DRAW=_C('GL_DYNAMIC_DRAW',0x88E8)
GL_DYNAMIC_READ=_C('GL_DYNAMIC_READ',0x88E9)
GL_EDGE_FLAG_ARRAY_BUFFER_BINDING=_C('GL_EDGE_FLAG_ARRAY_BUFFER_BINDING',0x889B)
GL_ELEMENT_ARRAY_BUFFER=_C('GL_ELEMENT_ARRAY_BUFFER',0x8893)
GL_ELEMENT_ARRAY_BUFFER_BINDING=_C('GL_ELEMENT_ARRAY_BUFFER_BINDING',0x8895)
GL_FOG_COORD=_C('GL_FOG_COORD',0x8451)
GL_FOG_COORDINATE_ARRAY_BUFFER_BINDING=_C('GL_FOG_COORDINATE_ARRAY_BUFFER_BINDING',0x889D)
GL_FOG_COORD_ARRAY=_C('GL_FOG_COORD_ARRAY',0x8457)
GL_FOG_COORD_ARRAY_BUFFER_BINDING=_C('GL_FOG_COORD_ARRAY_BUFFER_BINDING',0x889D)
GL_FOG_COORD_ARRAY_POINTER=_C('GL_FOG_COORD_ARRAY_POINTER',0x8456)
GL_FOG_COORD_ARRAY_STRIDE=_C('GL_FOG_COORD_ARRAY_STRIDE',0x8455)
GL_FOG_COORD_ARRAY_TYPE=_C('GL_FOG_COORD_ARRAY_TYPE',0x8454)
GL_FOG_COORD_SRC=_C('GL_FOG_COORD_SRC',0x8450)
GL_INDEX_ARRAY_BUFFER_BINDING=_C('GL_INDEX_ARRAY_BUFFER_BINDING',0x8899)
GL_NORMAL_ARRAY_BUFFER_BINDING=_C('GL_NORMAL_ARRAY_BUFFER_BINDING',0x8897)
GL_QUERY_COUNTER_BITS=_C('GL_QUERY_COUNTER_BITS',0x8864)
GL_QUERY_RESULT=_C('GL_QUERY_RESULT',0x8866)
GL_QUERY_RESULT_AVAILABLE=_C('GL_QUERY_RESULT_AVAILABLE',0x8867)
GL_READ_ONLY=_C('GL_READ_ONLY',0x88B8)
GL_READ_WRITE=_C('GL_READ_WRITE',0x88BA)
GL_SAMPLES_PASSED=_C('GL_SAMPLES_PASSED',0x8914)
GL_SECONDARY_COLOR_ARRAY_BUFFER_BINDING=_C('GL_SECONDARY_COLOR_ARRAY_BUFFER_BINDING',0x889C)
GL_SRC0_ALPHA=_C('GL_SRC0_ALPHA',0x8588)
GL_SRC0_RGB=_C('GL_SRC0_RGB',0x8580)
GL_SRC1_ALPHA=_C('GL_SRC1_ALPHA',0x8589)
GL_SRC1_RGB=_C('GL_SRC1_RGB',0x8581)
GL_SRC2_ALPHA=_C('GL_SRC2_ALPHA',0x858A)
GL_SRC2_RGB=_C('GL_SRC2_RGB',0x8582)
GL_STATIC_COPY=_C('GL_STATIC_COPY',0x88E6)
GL_STATIC_DRAW=_C('GL_STATIC_DRAW',0x88E4)
GL_STATIC_READ=_C('GL_STATIC_READ',0x88E5)
GL_STREAM_COPY=_C('GL_STREAM_COPY',0x88E2)
GL_STREAM_DRAW=_C('GL_STREAM_DRAW',0x88E0)
GL_STREAM_READ=_C('GL_STREAM_READ',0x88E1)
GL_TEXTURE_COORD_ARRAY_BUFFER_BINDING=_C('GL_TEXTURE_COORD_ARRAY_BUFFER_BINDING',0x889A)
GL_VERTEX_ARRAY_BUFFER_BINDING=_C('GL_VERTEX_ARRAY_BUFFER_BINDING',0x8896)
GL_VERTEX_ATTRIB_ARRAY_BUFFER_BINDING=_C('GL_VERTEX_ATTRIB_ARRAY_BUFFER_BINDING',0x889F)
GL_WEIGHT_ARRAY_BUFFER_BINDING=_C('GL_WEIGHT_ARRAY_BUFFER_BINDING',0x889E)
GL_WRITE_ONLY=_C('GL_WRITE_ONLY',0x88B9)
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glBeginQuery(target,id):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glBindBuffer(target,buffer):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizeiptr,ctypes.c_void_p,_cs.GLenum)
def glBufferData(target,size,data,usage):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLintptr,_cs.GLsizeiptr,ctypes.c_void_p)
def glBufferSubData(target,offset,size,data):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glDeleteBuffers(n,buffers):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glDeleteQueries(n,ids):pass
@_f
@_p.types(None,_cs.GLenum)
def glEndQuery(target):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glGenBuffers(n,buffers):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glGenQueries(n,ids):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetBufferParameteriv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLvoidpArray)
def glGetBufferPointerv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLintptr,_cs.GLsizeiptr,ctypes.c_void_p)
def glGetBufferSubData(target,offset,size,data):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLintArray)
def glGetQueryObjectiv(id,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLuintArray)
def glGetQueryObjectuiv(id,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetQueryiv(target,pname,params):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLuint)
def glIsBuffer(buffer):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLuint)
def glIsQuery(id):pass
@_f
@_p.types(ctypes.c_void_p,_cs.GLenum,_cs.GLenum)
def glMapBuffer(target,access):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLenum)
def glUnmapBuffer(target):pass



'''OpenGL extension ARB.invalidate_subdata

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.invalidate_subdata to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension adds a mechanism for an application to tell the GL that
	the previous contents of a subregion of an image or a range of a buffer 
	may be invalidated.
	
	GL implementations often include several memory spaces, each with 
	distinct performance characteristics, and the implementations 
	transparently move allocations between memory spaces. With this 
	extension, an application can tell the GL that the contents of a texture
	or buffer are no longer needed, and the implementation can avoid 
	transferring the data unnecessarily.
	
	Examples of when this may be useful include:
	
	(1) invalidating a multisample texture after resolving it into a non-
	    multisample texture.
	
	(2) invalidating depth/stencil buffers after using them to generate a color
	    buffer.
	
	(3) invalidating a subregion of a framebuffer rather than clearing it 
	    before rendering to it, when the whole subregion will be overwritten.
	
	(4) invalidating dynamically generated data (e.g. textures written by FBO 
	    rendering or CopyTexSubImage, buffers written by transform feedback,
	    etc.) after it is no longer needed but before the end of the frame.
	
	It is expected that the situations in which the GL will take advantage of
	this knowledge and achieve increased performance as a result of its use
	will be implementation-dependent. The first three examples may show 
	benefit on tiled renderers where some data won't need to be copied into 
	or out of on-chip memory. The fourth example may show a benefit in multi-
	GPU systems where some data won't need to be copied between GPUs.
	
	This extension is a superset of the EXT_discard_framebuffer extension 
	with the following additions:
	
	  - The parameters to InvalidateFramebufferEXT are extended for MRT support
	    and Desktop-GL-only buffer enums.
	
	  - New functions to invalidate a region of a texture image or buffer object
	    data store.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/invalidate_subdata.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.invalidate_subdata import *
from OpenGL.raw.GL.ARB.invalidate_subdata import _EXTENSION_NAME

def glInitInvalidateSubdataARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glInvalidateFramebuffer.attachments size not checked against numAttachments
glInvalidateFramebuffer=wrapper.wrapper(glInvalidateFramebuffer).setInputArraySize(
    'attachments', None
)
# INPUT glInvalidateSubFramebuffer.attachments size not checked against numAttachments
glInvalidateSubFramebuffer=wrapper.wrapper(glInvalidateSubFramebuffer).setInputArraySize(
    'attachments', None
)
### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_SGIS_detail_texture'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_SGIS_detail_texture',error_checker=_errors._error_checker)
GL_DETAIL_TEXTURE_2D_BINDING_SGIS=_C('GL_DETAIL_TEXTURE_2D_BINDING_SGIS',0x8096)
GL_DETAIL_TEXTURE_2D_SGIS=_C('GL_DETAIL_TEXTURE_2D_SGIS',0x8095)
GL_DETAIL_TEXTURE_FUNC_POINTS_SGIS=_C('GL_DETAIL_TEXTURE_FUNC_POINTS_SGIS',0x809C)
GL_DETAIL_TEXTURE_LEVEL_SGIS=_C('GL_DETAIL_TEXTURE_LEVEL_SGIS',0x809A)
GL_DETAIL_TEXTURE_MODE_SGIS=_C('GL_DETAIL_TEXTURE_MODE_SGIS',0x809B)
GL_LINEAR_DETAIL_ALPHA_SGIS=_C('GL_LINEAR_DETAIL_ALPHA_SGIS',0x8098)
GL_LINEAR_DETAIL_COLOR_SGIS=_C('GL_LINEAR_DETAIL_COLOR_SGIS',0x8099)
GL_LINEAR_DETAIL_SGIS=_C('GL_LINEAR_DETAIL_SGIS',0x8097)
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,arrays.GLfloatArray)
def glDetailTexFuncSGIS(target,n,points):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfloatArray)
def glGetDetailTexFuncSGIS(target,points):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_program_interface_query'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_program_interface_query',error_checker=_errors._error_checker)
GL_ACTIVE_RESOURCES=_C('GL_ACTIVE_RESOURCES',0x92F5)
GL_ACTIVE_VARIABLES=_C('GL_ACTIVE_VARIABLES',0x9305)
GL_ARRAY_SIZE=_C('GL_ARRAY_SIZE',0x92FB)
GL_ARRAY_STRIDE=_C('GL_ARRAY_STRIDE',0x92FE)
GL_ATOMIC_COUNTER_BUFFER=_C('GL_ATOMIC_COUNTER_BUFFER',0x92C0)
GL_ATOMIC_COUNTER_BUFFER_INDEX=_C('GL_ATOMIC_COUNTER_BUFFER_INDEX',0x9301)
GL_BLOCK_INDEX=_C('GL_BLOCK_INDEX',0x92FD)
GL_BUFFER_BINDING=_C('GL_BUFFER_BINDING',0x9302)
GL_BUFFER_DATA_SIZE=_C('GL_BUFFER_DATA_SIZE',0x9303)
GL_BUFFER_VARIABLE=_C('GL_BUFFER_VARIABLE',0x92E5)
GL_COMPATIBLE_SUBROUTINES=_C('GL_COMPATIBLE_SUBROUTINES',0x8E4B)
GL_COMPUTE_SUBROUTINE=_C('GL_COMPUTE_SUBROUTINE',0x92ED)
GL_COMPUTE_SUBROUTINE_UNIFORM=_C('GL_COMPUTE_SUBROUTINE_UNIFORM',0x92F3)
GL_FRAGMENT_SUBROUTINE=_C('GL_FRAGMENT_SUBROUTINE',0x92EC)
GL_FRAGMENT_SUBROUTINE_UNIFORM=_C('GL_FRAGMENT_SUBROUTINE_UNIFORM',0x92F2)
GL_GEOMETRY_SUBROUTINE=_C('GL_GEOMETRY_SUBROUTINE',0x92EB)
GL_GEOMETRY_SUBROUTINE_UNIFORM=_C('GL_GEOMETRY_SUBROUTINE_UNIFORM',0x92F1)
GL_IS_PER_PATCH=_C('GL_IS_PER_PATCH',0x92E7)
GL_IS_ROW_MAJOR=_C('GL_IS_ROW_MAJOR',0x9300)
GL_LOCATION=_C('GL_LOCATION',0x930E)
GL_LOCATION_INDEX=_C('GL_LOCATION_INDEX',0x930F)
GL_MATRIX_STRIDE=_C('GL_MATRIX_STRIDE',0x92FF)
GL_MAX_NAME_LENGTH=_C('GL_MAX_NAME_LENGTH',0x92F6)
GL_MAX_NUM_ACTIVE_VARIABLES=_C('GL_MAX_NUM_ACTIVE_VARIABLES',0x92F7)
GL_MAX_NUM_COMPATIBLE_SUBROUTINES=_C('GL_MAX_NUM_COMPATIBLE_SUBROUTINES',0x92F8)
GL_NAME_LENGTH=_C('GL_NAME_LENGTH',0x92F9)
GL_NUM_ACTIVE_VARIABLES=_C('GL_NUM_ACTIVE_VARIABLES',0x9304)
GL_NUM_COMPATIBLE_SUBROUTINES=_C('GL_NUM_COMPATIBLE_SUBROUTINES',0x8E4A)
GL_OFFSET=_C('GL_OFFSET',0x92FC)
GL_PROGRAM_INPUT=_C('GL_PROGRAM_INPUT',0x92E3)
GL_PROGRAM_OUTPUT=_C('GL_PROGRAM_OUTPUT',0x92E4)
GL_REFERENCED_BY_COMPUTE_SHADER=_C('GL_REFERENCED_BY_COMPUTE_SHADER',0x930B)
GL_REFERENCED_BY_FRAGMENT_SHADER=_C('GL_REFERENCED_BY_FRAGMENT_SHADER',0x930A)
GL_REFERENCED_BY_GEOMETRY_SHADER=_C('GL_REFERENCED_BY_GEOMETRY_SHADER',0x9309)
GL_REFERENCED_BY_TESS_CONTROL_SHADER=_C('GL_REFERENCED_BY_TESS_CONTROL_SHADER',0x9307)
GL_REFERENCED_BY_TESS_EVALUATION_SHADER=_C('GL_REFERENCED_BY_TESS_EVALUATION_SHADER',0x9308)
GL_REFERENCED_BY_VERTEX_SHADER=_C('GL_REFERENCED_BY_VERTEX_SHADER',0x9306)
GL_SHADER_STORAGE_BLOCK=_C('GL_SHADER_STORAGE_BLOCK',0x92E6)
GL_TESS_CONTROL_SUBROUTINE=_C('GL_TESS_CONTROL_SUBROUTINE',0x92E9)
GL_TESS_CONTROL_SUBROUTINE_UNIFORM=_C('GL_TESS_CONTROL_SUBROUTINE_UNIFORM',0x92EF)
GL_TESS_EVALUATION_SUBROUTINE=_C('GL_TESS_EVALUATION_SUBROUTINE',0x92EA)
GL_TESS_EVALUATION_SUBROUTINE_UNIFORM=_C('GL_TESS_EVALUATION_SUBROUTINE_UNIFORM',0x92F0)
GL_TOP_LEVEL_ARRAY_SIZE=_C('GL_TOP_LEVEL_ARRAY_SIZE',0x930C)
GL_TOP_LEVEL_ARRAY_STRIDE=_C('GL_TOP_LEVEL_ARRAY_STRIDE',0x930D)
GL_TRANSFORM_FEEDBACK_VARYING=_C('GL_TRANSFORM_FEEDBACK_VARYING',0x92F4)
GL_TYPE=_C('GL_TYPE',0x92FA)
GL_UNIFORM=_C('GL_UNIFORM',0x92E1)
GL_UNIFORM_BLOCK=_C('GL_UNIFORM_BLOCK',0x92E2)
GL_VERTEX_SUBROUTINE=_C('GL_VERTEX_SUBROUTINE',0x92E8)
GL_VERTEX_SUBROUTINE_UNIFORM=_C('GL_VERTEX_SUBROUTINE_UNIFORM',0x92EE)
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetProgramInterfaceiv(program,programInterface,pname,params):pass
@_f
@_p.types(_cs.GLuint,_cs.GLuint,_cs.GLenum,arrays.GLcharArray)
def glGetProgramResourceIndex(program,programInterface,name):pass
@_f
@_p.types(_cs.GLint,_cs.GLuint,_cs.GLenum,arrays.GLcharArray)
def glGetProgramResourceLocation(program,programInterface,name):pass
@_f
@_p.types(_cs.GLint,_cs.GLuint,_cs.GLenum,arrays.GLcharArray)
def glGetProgramResourceLocationIndex(program,programInterface,name):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLuint,_cs.GLsizei,arrays.GLsizeiArray,arrays.GLcharArray)
def glGetProgramResourceName(program,programInterface,index,bufSize,length,name):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLuint,_cs.GLsizei,arrays.GLuintArray,_cs.GLsizei,arrays.GLsizeiArray,arrays.GLintArray)
def glGetProgramResourceiv(program,programInterface,index,propCount,props,bufSize,length,params):pass



from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _types as _base
GLfixed = _base._defineType('GLfixed', ctypes.c_int32, int )
GLclampx = _base._defineType('GLclampx', ctypes.c_int32, int )



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_OES_tessellation_shader'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_OES_tessellation_shader',error_checker=_errors._error_checker)
GL_CCW=_C('GL_CCW',0x0901)
GL_CW=_C('GL_CW',0x0900)
GL_EQUAL=_C('GL_EQUAL',0x0202)
GL_FRACTIONAL_EVEN_OES=_C('GL_FRACTIONAL_EVEN_OES',0x8E7C)
GL_FRACTIONAL_ODD_OES=_C('GL_FRACTIONAL_ODD_OES',0x8E7B)
GL_ISOLINES_OES=_C('GL_ISOLINES_OES',0x8E7A)
GL_IS_PER_PATCH_OES=_C('GL_IS_PER_PATCH_OES',0x92E7)
GL_MAX_COMBINED_TESS_CONTROL_UNIFORM_COMPONENTS_OES=_C('GL_MAX_COMBINED_TESS_CONTROL_UNIFORM_COMPONENTS_OES',0x8E1E)
GL_MAX_COMBINED_TESS_EVALUATION_UNIFORM_COMPONENTS_OES=_C('GL_MAX_COMBINED_TESS_EVALUATION_UNIFORM_COMPONENTS_OES',0x8E1F)
GL_MAX_PATCH_VERTICES_OES=_C('GL_MAX_PATCH_VERTICES_OES',0x8E7D)
GL_MAX_TESS_CONTROL_ATOMIC_COUNTERS_OES=_C('GL_MAX_TESS_CONTROL_ATOMIC_COUNTERS_OES',0x92D3)
GL_MAX_TESS_CONTROL_ATOMIC_COUNTER_BUFFERS_OES=_C('GL_MAX_TESS_CONTROL_ATOMIC_COUNTER_BUFFERS_OES',0x92CD)
GL_MAX_TESS_CONTROL_IMAGE_UNIFORMS_OES=_C('GL_MAX_TESS_CONTROL_IMAGE_UNIFORMS_OES',0x90CB)
GL_MAX_TESS_CONTROL_INPUT_COMPONENTS_OES=_C('GL_MAX_TESS_CONTROL_INPUT_COMPONENTS_OES',0x886C)
GL_MAX_TESS_CONTROL_OUTPUT_COMPONENTS_OES=_C('GL_MAX_TESS_CONTROL_OUTPUT_COMPONENTS_OES',0x8E83)
GL_MAX_TESS_CONTROL_SHADER_STORAGE_BLOCKS_OES=_C('GL_MAX_TESS_CONTROL_SHADER_STORAGE_BLOCKS_OES',0x90D8)
GL_MAX_TESS_CONTROL_TEXTURE_IMAGE_UNITS_OES=_C('GL_MAX_TESS_CONTROL_TEXTURE_IMAGE_UNITS_OES',0x8E81)
GL_MAX_TESS_CONTROL_TOTAL_OUTPUT_COMPONENTS_OES=_C('GL_MAX_TESS_CONTROL_TOTAL_OUTPUT_COMPONENTS_OES',0x8E85)
GL_MAX_TESS_CONTROL_UNIFORM_BLOCKS_OES=_C('GL_MAX_TESS_CONTROL_UNIFORM_BLOCKS_OES',0x8E89)
GL_MAX_TESS_CONTROL_UNIFORM_COMPONENTS_OES=_C('GL_MAX_TESS_CONTROL_UNIFORM_COMPONENTS_OES',0x8E7F)
GL_MAX_TESS_EVALUATION_ATOMIC_COUNTERS_OES=_C('GL_MAX_TESS_EVALUATION_ATOMIC_COUNTERS_OES',0x92D4)
GL_MAX_TESS_EVALUATION_ATOMIC_COUNTER_BUFFERS_OES=_C('GL_MAX_TESS_EVALUATION_ATOMIC_COUNTER_BUFFERS_OES',0x92CE)
GL_MAX_TESS_EVALUATION_IMAGE_UNIFORMS_OES=_C('GL_MAX_TESS_EVALUATION_IMAGE_UNIFORMS_OES',0x90CC)
GL_MAX_TESS_EVALUATION_INPUT_COMPONENTS_OES=_C('GL_MAX_TESS_EVALUATION_INPUT_COMPONENTS_OES',0x886D)
GL_MAX_TESS_EVALUATION_OUTPUT_COMPONENTS_OES=_C('GL_MAX_TESS_EVALUATION_OUTPUT_COMPONENTS_OES',0x8E86)
GL_MAX_TESS_EVALUATION_SHADER_STORAGE_BLOCKS_OES=_C('GL_MAX_TESS_EVALUATION_SHADER_STORAGE_BLOCKS_OES',0x90D9)
GL_MAX_TESS_EVALUATION_TEXTURE_IMAGE_UNITS_OES=_C('GL_MAX_TESS_EVALUATION_TEXTURE_IMAGE_UNITS_OES',0x8E82)
GL_MAX_TESS_EVALUATION_UNIFORM_BLOCKS_OES=_C('GL_MAX_TESS_EVALUATION_UNIFORM_BLOCKS_OES',0x8E8A)
GL_MAX_TESS_EVALUATION_UNIFORM_COMPONENTS_OES=_C('GL_MAX_TESS_EVALUATION_UNIFORM_COMPONENTS_OES',0x8E80)
GL_MAX_TESS_GEN_LEVEL_OES=_C('GL_MAX_TESS_GEN_LEVEL_OES',0x8E7E)
GL_MAX_TESS_PATCH_COMPONENTS_OES=_C('GL_MAX_TESS_PATCH_COMPONENTS_OES',0x8E84)
GL_PATCHES_OES=_C('GL_PATCHES_OES',0x000E)
GL_PATCH_VERTICES_OES=_C('GL_PATCH_VERTICES_OES',0x8E72)
GL_PRIMITIVE_RESTART_FOR_PATCHES_SUPPORTED_OES=_C('GL_PRIMITIVE_RESTART_FOR_PATCHES_SUPPORTED_OES',0x8221)
GL_QUADS_OES=_C('GL_QUADS_OES',0x0007)
GL_REFERENCED_BY_TESS_CONTROL_SHADER_OES=_C('GL_REFERENCED_BY_TESS_CONTROL_SHADER_OES',0x9307)
GL_REFERENCED_BY_TESS_EVALUATION_SHADER_OES=_C('GL_REFERENCED_BY_TESS_EVALUATION_SHADER_OES',0x9308)
GL_TESS_CONTROL_OUTPUT_VERTICES_OES=_C('GL_TESS_CONTROL_OUTPUT_VERTICES_OES',0x8E75)
GL_TESS_CONTROL_SHADER_BIT_OES=_C('GL_TESS_CONTROL_SHADER_BIT_OES',0x00000008)
GL_TESS_CONTROL_SHADER_OES=_C('GL_TESS_CONTROL_SHADER_OES',0x8E88)
GL_TESS_EVALUATION_SHADER_BIT_OES=_C('GL_TESS_EVALUATION_SHADER_BIT_OES',0x00000010)
GL_TESS_EVALUATION_SHADER_OES=_C('GL_TESS_EVALUATION_SHADER_OES',0x8E87)
GL_TESS_GEN_MODE_OES=_C('GL_TESS_GEN_MODE_OES',0x8E76)
GL_TESS_GEN_POINT_MODE_OES=_C('GL_TESS_GEN_POINT_MODE_OES',0x8E79)
GL_TESS_GEN_SPACING_OES=_C('GL_TESS_GEN_SPACING_OES',0x8E77)
GL_TESS_GEN_VERTEX_ORDER_OES=_C('GL_TESS_GEN_VERTEX_ORDER_OES',0x8E78)
GL_TRIANGLES=_C('GL_TRIANGLES',0x0004)
@_f
@_p.types(None,_cs.GLenum,_cs.GLint)
def glPatchParameteriOES(pname,value):pass



'''OpenGL extension ARB.gpu_shader_fp64

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.gpu_shader_fp64 to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension allows GLSL shaders to use double-precision floating-point
	data types, including vectors and matrices of doubles.  Doubles may be
	used as inputs, outputs, and uniforms.  
	
	The shading language supports various arithmetic and comparison operators
	on double-precision scalar, vector, and matrix types, and provides a set
	of built-in functions including:
	
	  * square roots and inverse square roots;
	
	  * fused floating-point multiply-add operations;
	
	  * splitting a floating-point number into a significand and exponent
	    (frexp), or building a floating-point number from a significand and
	    exponent (ldexp);
	
	  * absolute value, sign tests, various functions to round to an integer
	    value, modulus, minimum, maximum, clamping, blending two values, step
	    functions, and testing for infinity and NaN values;
	
	  * packing and unpacking doubles into a pair of 32-bit unsigned integers;
	
	  * matrix component-wise multiplication, and computation of outer
	    products, transposes, determinants, and inverses; and
	
	  * vector relational functions.
	
	Double-precision versions of angle, trigonometry, and exponential
	functions are not supported.
	
	Implicit conversions are supported from integer and single-precision
	floating-point values to doubles, and this extension uses the relaxed
	function overloading rules specified by the ARB_gpu_shader5 extension to
	resolve ambiguities.
	
	This extension provides API functions for specifying double-precision
	uniforms in the default uniform block, including functions similar to the
	uniform functions added by EXT_direct_state_access (if supported).
	
	This extension provides an "LF" suffix for specifying double-precision
	constants.  Floating-point constants without a suffix in GLSL are treated
	as single-precision values for backward compatibility with versions not
	supporting doubles; similar constants are treated as double-precision
	values in the "C" programming language.
	
	This extension does not support interpolation of double-precision values;
	doubles used as fragment shader inputs must be qualified as "flat".
	Additionally, this extension does not allow vertex attributes with 64-bit
	components.  That support is added separately by EXT_vertex_attrib_64bit.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/gpu_shader_fp64.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.gpu_shader_fp64 import *
from OpenGL.raw.GL.ARB.gpu_shader_fp64 import _EXTENSION_NAME

def glInitGpuShaderFp64ARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glUniform1dv.value size not checked against count
glUniform1dv=wrapper.wrapper(glUniform1dv).setInputArraySize(
    'value', None
)
# INPUT glUniform2dv.value size not checked against count*2
glUniform2dv=wrapper.wrapper(glUniform2dv).setInputArraySize(
    'value', None
)
# INPUT glUniform3dv.value size not checked against count*3
glUniform3dv=wrapper.wrapper(glUniform3dv).setInputArraySize(
    'value', None
)
# INPUT glUniform4dv.value size not checked against count*4
glUniform4dv=wrapper.wrapper(glUniform4dv).setInputArraySize(
    'value', None
)
# INPUT glUniformMatrix2dv.value size not checked against count*4
glUniformMatrix2dv=wrapper.wrapper(glUniformMatrix2dv).setInputArraySize(
    'value', None
)
# INPUT glUniformMatrix3dv.value size not checked against count*9
glUniformMatrix3dv=wrapper.wrapper(glUniformMatrix3dv).setInputArraySize(
    'value', None
)
# INPUT glUniformMatrix4dv.value size not checked against count*16
glUniformMatrix4dv=wrapper.wrapper(glUniformMatrix4dv).setInputArraySize(
    'value', None
)
# INPUT glUniformMatrix2x3dv.value size not checked against count*6
glUniformMatrix2x3dv=wrapper.wrapper(glUniformMatrix2x3dv).setInputArraySize(
    'value', None
)
# INPUT glUniformMatrix2x4dv.value size not checked against count*8
glUniformMatrix2x4dv=wrapper.wrapper(glUniformMatrix2x4dv).setInputArraySize(
    'value', None
)
# INPUT glUniformMatrix3x2dv.value size not checked against count*6
glUniformMatrix3x2dv=wrapper.wrapper(glUniformMatrix3x2dv).setInputArraySize(
    'value', None
)
# INPUT glUniformMatrix3x4dv.value size not checked against count*12
glUniformMatrix3x4dv=wrapper.wrapper(glUniformMatrix3x4dv).setInputArraySize(
    'value', None
)
# INPUT glUniformMatrix4x2dv.value size not checked against count*8
glUniformMatrix4x2dv=wrapper.wrapper(glUniformMatrix4x2dv).setInputArraySize(
    'value', None
)
# INPUT glUniformMatrix4x3dv.value size not checked against count*12
glUniformMatrix4x3dv=wrapper.wrapper(glUniformMatrix4x3dv).setInputArraySize(
    'value', None
)
# OUTPUT glGetUniformdv.params COMPSIZE(program, location) 
### END AUTOGENERATED SECTION


"""Array-size annotations for OpenGL.raw.GLU

Automatically generated by the generateraw script, do not edit!
"""
from OpenGL.raw import GLU as raw

from ctypes import *
from OpenGL import platform, arrays
from OpenGL.constant import Constant
from OpenGL.raw.GL import _types as GL_types
GLvoid = GL_types.GLvoid



gluCheckExtension = arrays.setInputArraySizeType(
    arrays.setInputArraySizeType(
        raw.gluCheckExtension,
        None, # XXX Could not determine size of argument extName for gluCheckExtension arrays.GLubyteArray
        arrays.GLubyteArray, 
        'extName',
    ),
    None, # XXX Could not determine size of argument extString for gluCheckExtension arrays.GLubyteArray
    arrays.GLubyteArray, 
    'extString',
)

gluGetNurbsProperty = arrays.setInputArraySizeType(
    raw.gluGetNurbsProperty,
    None, # XXX Could not determine size of argument data for gluGetNurbsProperty arrays.GLfloatArray
    arrays.GLfloatArray, 
    'data',
)

gluGetTessProperty = arrays.setInputArraySizeType(
    raw.gluGetTessProperty,
    None, # XXX Could not determine size of argument data for gluGetTessProperty arrays.GLdoubleArray
    arrays.GLdoubleArray, 
    'data',
)

gluLoadSamplingMatrices = arrays.setInputArraySizeType(
    arrays.setInputArraySizeType(
        arrays.setInputArraySizeType(
            raw.gluLoadSamplingMatrices,
            None, # XXX Could not determine size of argument model for gluLoadSamplingMatrices arrays.GLfloatArray
            arrays.GLfloatArray, 
            'model',
        ),
        None, # XXX Could not determine size of argument perspective for gluLoadSamplingMatrices arrays.GLfloatArray
        arrays.GLfloatArray, 
        'perspective',
    ),
    None, # XXX Could not determine size of argument view for gluLoadSamplingMatrices arrays.GLintArray
    arrays.GLintArray, 
    'view',
)

gluNurbsCurve = arrays.setInputArraySizeType(
    arrays.setInputArraySizeType(
        raw.gluNurbsCurve,
        None, # XXX Could not determine size of argument knots for gluNurbsCurve arrays.GLfloatArray
        arrays.GLfloatArray, 
        'knots',
    ),
    None, # XXX Could not determine size of argument control for gluNurbsCurve arrays.GLfloatArray
    arrays.GLfloatArray, 
    'control',
)

gluNurbsSurface = arrays.setInputArraySizeType(
    arrays.setInputArraySizeType(
        arrays.setInputArraySizeType(
            raw.gluNurbsSurface,
            None, # XXX Could not determine size of argument sKnots for gluNurbsSurface arrays.GLfloatArray
            arrays.GLfloatArray, 
            'sKnots',
        ),
        None, # XXX Could not determine size of argument tKnots for gluNurbsSurface arrays.GLfloatArray
        arrays.GLfloatArray, 
        'tKnots',
    ),
    None, # XXX Could not determine size of argument control for gluNurbsSurface arrays.GLfloatArray
    arrays.GLfloatArray, 
    'control',
)

gluPickMatrix = arrays.setInputArraySizeType(
    raw.gluPickMatrix,
    None, # XXX Could not determine size of argument viewport for gluPickMatrix arrays.GLintArray
    arrays.GLintArray, 
    'viewport',
)

gluProject = arrays.setInputArraySizeType(
    arrays.setInputArraySizeType(
        arrays.setInputArraySizeType(
            arrays.setInputArraySizeType(
                arrays.setInputArraySizeType(
                    arrays.setInputArraySizeType(
                        raw.gluProject,
                        None, # XXX Could not determine size of argument model for gluProject arrays.GLdoubleArray
                        arrays.GLdoubleArray, 
                        'model',
                    ),
                    None, # XXX Could not determine size of argument proj for gluProject arrays.GLdoubleArray
                    arrays.GLdoubleArray, 
                    'proj',
                ),
                None, # XXX Could not determine size of argument view for gluProject arrays.GLintArray
                arrays.GLintArray, 
                'view',
            ),
            None, # XXX Could not determine size of argument winX for gluProject arrays.GLdoubleArray
            arrays.GLdoubleArray, 
            'winX',
        ),
        None, # XXX Could not determine size of argument winY for gluProject arrays.GLdoubleArray
        arrays.GLdoubleArray, 
        'winY',
    ),
    None, # XXX Could not determine size of argument winZ for gluProject arrays.GLdoubleArray
    arrays.GLdoubleArray, 
    'winZ',
)

gluPwlCurve = arrays.setInputArraySizeType(
    raw.gluPwlCurve,
    None, # XXX Could not determine size of argument data for gluPwlCurve arrays.GLfloatArray
    arrays.GLfloatArray, 
    'data',
)

gluTessVertex = arrays.setInputArraySizeType(
    raw.gluTessVertex,
    None, # XXX Could not determine size of argument location for gluTessVertex arrays.GLdoubleArray
    arrays.GLdoubleArray, 
    'location',
)

gluUnProject = arrays.setInputArraySizeType(
    arrays.setInputArraySizeType(
        arrays.setInputArraySizeType(
            arrays.setInputArraySizeType(
                arrays.setInputArraySizeType(
                    arrays.setInputArraySizeType(
                        raw.gluUnProject,
                        None, # XXX Could not determine size of argument model for gluUnProject arrays.GLdoubleArray
                        arrays.GLdoubleArray, 
                        'model',
                    ),
                    None, # XXX Could not determine size of argument proj for gluUnProject arrays.GLdoubleArray
                    arrays.GLdoubleArray, 
                    'proj',
                ),
                None, # XXX Could not determine size of argument view for gluUnProject arrays.GLintArray
                arrays.GLintArray, 
                'view',
            ),
            None, # XXX Could not determine size of argument objX for gluUnProject arrays.GLdoubleArray
            arrays.GLdoubleArray, 
            'objX',
        ),
        None, # XXX Could not determine size of argument objY for gluUnProject arrays.GLdoubleArray
        arrays.GLdoubleArray, 
        'objY',
    ),
    None, # XXX Could not determine size of argument objZ for gluUnProject arrays.GLdoubleArray
    arrays.GLdoubleArray, 
    'objZ',
)

gluUnProject4 = arrays.setInputArraySizeType(
    arrays.setInputArraySizeType(
        arrays.setInputArraySizeType(
            arrays.setInputArraySizeType(
                arrays.setInputArraySizeType(
                    arrays.setInputArraySizeType(
                        arrays.setInputArraySizeType(
                            raw.gluUnProject4,
                            None, # XXX Could not determine size of argument model for gluUnProject4 arrays.GLdoubleArray
                            arrays.GLdoubleArray, 
                            'model',
                        ),
                        None, # XXX Could not determine size of argument proj for gluUnProject4 arrays.GLdoubleArray
                        arrays.GLdoubleArray, 
                        'proj',
                    ),
                    None, # XXX Could not determine size of argument view for gluUnProject4 arrays.GLintArray
                    arrays.GLintArray, 
                    'view',
                ),
                None, # XXX Could not determine size of argument objX for gluUnProject4 arrays.GLdoubleArray
                arrays.GLdoubleArray, 
                'objX',
            ),
            None, # XXX Could not determine size of argument objY for gluUnProject4 arrays.GLdoubleArray
            arrays.GLdoubleArray, 
            'objY',
        ),
        None, # XXX Could not determine size of argument objZ for gluUnProject4 arrays.GLdoubleArray
        arrays.GLdoubleArray, 
        'objZ',
    ),
    None, # XXX Could not determine size of argument objW for gluUnProject4 arrays.GLdoubleArray
    arrays.GLdoubleArray, 
    'objW',
)

__all__ = [
    'gluCheckExtension',
    'gluGetNurbsProperty',
    'gluGetTessProperty',
    'gluLoadSamplingMatrices',
    'gluNurbsCurve',
    'gluNurbsSurface',
    'gluPickMatrix',
    'gluProject',
    'gluPwlCurve',
    'gluTessVertex',
    'gluUnProject',
    'gluUnProject4'
]



'''OpenGL extension NV.depth_buffer_float

This module customises the behaviour of the 
OpenGL.raw.GL.NV.depth_buffer_float to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides new texture internal formats whose depth
	components are stored as 32-bit floating-point values, rather than the
	normalized unsigned integers used in existing depth formats.
	Floating-point depth textures support all the functionality supported for
	fixed-point depth textures, including shadow mapping and rendering support
	via EXT_framebuffer_object.  Floating-point depth textures can store
	values outside the range [0,1].
	
	By default, OpenGL entry points taking depth values implicitly clamp the
	values to the range [0,1].  This extension provides new DepthClear,
	DepthRange, and DepthBoundsEXT entry points that allow applications to
	specify depth values that are not clamped.
	
	Additionally, this extension provides new packed depth/stencil pixel
	formats (see EXT_packed_depth_stencil) that have 64-bit pixels consisting
	of a 32-bit floating-point depth value, 8 bits of stencil, and 24 unused
	bites.  A packed depth/stencil texture internal format is also provided.
	
	This extension does not provide support for WGL or GLX pixel formats with
	floating-point depth buffers.  The existing (but not commonly used)
	WGL_EXT_depth_float extension could be used for this purpose.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/depth_buffer_float.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.depth_buffer_float import *
from OpenGL.raw.GL.NV.depth_buffer_float import _EXTENSION_NAME

def glInitDepthBufferFloatNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_NV_float_buffer'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_NV_float_buffer',error_checker=_errors._error_checker)
GL_FLOAT_CLEAR_COLOR_VALUE_NV=_C('GL_FLOAT_CLEAR_COLOR_VALUE_NV',0x888D)
GL_FLOAT_R16_NV=_C('GL_FLOAT_R16_NV',0x8884)
GL_FLOAT_R32_NV=_C('GL_FLOAT_R32_NV',0x8885)
GL_FLOAT_RG16_NV=_C('GL_FLOAT_RG16_NV',0x8886)
GL_FLOAT_RG32_NV=_C('GL_FLOAT_RG32_NV',0x8887)
GL_FLOAT_RGB16_NV=_C('GL_FLOAT_RGB16_NV',0x8888)
GL_FLOAT_RGB32_NV=_C('GL_FLOAT_RGB32_NV',0x8889)
GL_FLOAT_RGBA16_NV=_C('GL_FLOAT_RGBA16_NV',0x888A)
GL_FLOAT_RGBA32_NV=_C('GL_FLOAT_RGBA32_NV',0x888B)
GL_FLOAT_RGBA_MODE_NV=_C('GL_FLOAT_RGBA_MODE_NV',0x888E)
GL_FLOAT_RGBA_NV=_C('GL_FLOAT_RGBA_NV',0x8883)
GL_FLOAT_RGB_NV=_C('GL_FLOAT_RGB_NV',0x8882)
GL_FLOAT_RG_NV=_C('GL_FLOAT_RG_NV',0x8881)
GL_FLOAT_R_NV=_C('GL_FLOAT_R_NV',0x8880)
GL_TEXTURE_FLOAT_COMPONENTS_NV=_C('GL_TEXTURE_FLOAT_COMPONENTS_NV',0x888C)




'''OpenGL extension ARB.arrays_of_arrays

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.arrays_of_arrays to provide a more 
Python-friendly API

Overview (from the spec)
	
	Multi-dimensional arrays are a frequently requested feature.  This extension
	removes the restriciton that arrays cannot be formed into arrays, allowing
	arrays of arrays to be declared.  Technically, removing this restriction is 
	all that is necessary to enable this feature, but it is worthwhile showing
	what the result of doing that looks like.
	
	The following will be true of arrays of arrays
	
	- They will first class objects.  (They know their size, can be passed by 
	  copy-in semantics to functions, etc.)
	
	- They will only be one-dimensional arrays of other first class objects.
	  (arrays are already first class objects).
	
	- The syntax
	
	    vec4 a[3][2];
	
	  Declares a one-dimensional array of size 3 of one-dimensional arrays of 
	  size 2 of vec4s.  Also, these syntaxes do the same thing:
	
	    vec4[2] a[3];
	    vec4[3][2] a;
	
	  or, looking at more dimensions, these are all the same
	
	    int a[1][2][3][4][5][6];
	
	    int[1][2][3][4][5][6] a;
	
	    int[4][5][6] a[1][2][3];
	
	  note this latter is equivalent to C, in meaning the same thing, if done as
	
	    typedef int int456[4][5][6];
	
	    int456 a[1][2][3];
	
	  that is, this GLSL proposal matches C behavior in this way.  The type needed for
	  both constructors and nameless parameters is:
	
	     int[1][2][3][4][5][6]
	
	- This type could be declared as a formal parameter in a function prototype as
	
	    void foo(vec4[3][2]);
	
	- Accessing is done as
	
	    a[x][y]  // x selects which array of size 2 is desired
	             // y selects which vec4 is desired
	
	    a[x]     // this results in a one-dimensional array, with all rights and
	             // priviledges implied
	
	- The .length() operator works as normal:
	
	    a.length()     // this is 3
	    a[x].length()  // this is 2
	
	- The constructor for the above is
	
	    vec4[3][2](vec4[2](vec4(0.0), vec4(1.0)),   
	               vec4[2](vec4(0.0), vec4(1.0)),   
	               vec4[2](vec4(0.0), vec4(1.0)))
	
	- Initializers for the above are
	
	    vec4 a[3][2] = vec4[3][2](vec4[2](vec4(0.0), vec4(1.0)),   
	                              vec4[2](vec4(0.0), vec4(1.0)),   
	                              vec4[2](vec4(0.0), vec4(1.0)));
	
	    // or
	
	    vec4 a[3][2] = {vec4[2](vec4(0.0), vec4(1.0)),   
	                    vec4[2](vec4(0.0), vec4(1.0)),   
	                    vec4[2](vec4(0.0), vec4(1.0))) };
	
	    // or 
	
	    vec4 a[3][2] = {{ vec4(0.0), vec4(1.0) },   
	                    { vec4(0.0), vec4(1.0) },   
	                    { vec4(0.0), vec4(1.0) }  };  // requires matching nesting of 
	                                                  // {} with object's hierarchy
	
	
	Note that all the above is naturally already specified in the core 
	specification.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/arrays_of_arrays.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.arrays_of_arrays import *
from OpenGL.raw.GL.ARB.arrays_of_arrays import _EXTENSION_NAME

def glInitArraysOfArraysARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension DL.stereo_control

This module customises the behaviour of the 
OpenGL.raw.WGL.DL.stereo_control to provide a more 
Python-friendly API

Overview (from the spec)
	
	The stereo extension provides an interface for manipulating the 
	emitter signal from the video adapter used to drive lcd shutter 
	glasses used for stereoscopic viewing.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/DL/stereo_control.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.WGL import _types, _glgets
from OpenGL.raw.WGL.DL.stereo_control import *
from OpenGL.raw.WGL.DL.stereo_control import _EXTENSION_NAME

def glInitStereoControlDL():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_index_func'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_index_func',error_checker=_errors._error_checker)
GL_INDEX_TEST_EXT=_C('GL_INDEX_TEST_EXT',0x81B5)
GL_INDEX_TEST_FUNC_EXT=_C('GL_INDEX_TEST_FUNC_EXT',0x81B6)
GL_INDEX_TEST_REF_EXT=_C('GL_INDEX_TEST_REF_EXT',0x81B7)
@_f
@_p.types(None,_cs.GLenum,_cs.GLclampf)
def glIndexFuncEXT(func,ref):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_APPLE_sync'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_APPLE_sync',error_checker=_errors._error_checker)
GL_ALREADY_SIGNALED_APPLE=_C('GL_ALREADY_SIGNALED_APPLE',0x911A)
GL_CONDITION_SATISFIED_APPLE=_C('GL_CONDITION_SATISFIED_APPLE',0x911C)
GL_MAX_SERVER_WAIT_TIMEOUT_APPLE=_C('GL_MAX_SERVER_WAIT_TIMEOUT_APPLE',0x9111)
GL_OBJECT_TYPE_APPLE=_C('GL_OBJECT_TYPE_APPLE',0x9112)
GL_SIGNALED_APPLE=_C('GL_SIGNALED_APPLE',0x9119)
GL_SYNC_CONDITION_APPLE=_C('GL_SYNC_CONDITION_APPLE',0x9113)
GL_SYNC_FENCE_APPLE=_C('GL_SYNC_FENCE_APPLE',0x9116)
GL_SYNC_FLAGS_APPLE=_C('GL_SYNC_FLAGS_APPLE',0x9115)
GL_SYNC_FLUSH_COMMANDS_BIT_APPLE=_C('GL_SYNC_FLUSH_COMMANDS_BIT_APPLE',0x00000001)
GL_SYNC_GPU_COMMANDS_COMPLETE_APPLE=_C('GL_SYNC_GPU_COMMANDS_COMPLETE_APPLE',0x9117)
GL_SYNC_OBJECT_APPLE=_C('GL_SYNC_OBJECT_APPLE',0x8A53)
GL_SYNC_STATUS_APPLE=_C('GL_SYNC_STATUS_APPLE',0x9114)
GL_TIMEOUT_EXPIRED_APPLE=_C('GL_TIMEOUT_EXPIRED_APPLE',0x911B)
GL_TIMEOUT_IGNORED_APPLE=_C('GL_TIMEOUT_IGNORED_APPLE',0xFFFFFFFFFFFFFFFF)
GL_UNSIGNALED_APPLE=_C('GL_UNSIGNALED_APPLE',0x9118)
GL_WAIT_FAILED_APPLE=_C('GL_WAIT_FAILED_APPLE',0x911D)
@_f
@_p.types(_cs.GLenum,_cs.GLsync,_cs.GLbitfield,_cs.GLuint64)
def glClientWaitSyncAPPLE(sync,flags,timeout):pass
@_f
@_p.types(None,_cs.GLsync)
def glDeleteSyncAPPLE(sync):pass
@_f
@_p.types(_cs.GLsync,_cs.GLenum,_cs.GLbitfield)
def glFenceSyncAPPLE(condition,flags):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLint64Array)
def glGetInteger64vAPPLE(pname,params):pass
@_f
@_p.types(None,_cs.GLsync,_cs.GLenum,_cs.GLsizei,arrays.GLsizeiArray,arrays.GLintArray)
def glGetSyncivAPPLE(sync,pname,bufSize,length,values):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLsync)
def glIsSyncAPPLE(sync):pass
@_f
@_p.types(None,_cs.GLsync,_cs.GLbitfield,_cs.GLuint64)
def glWaitSyncAPPLE(sync,flags,timeout):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_texture_multisample'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_texture_multisample',error_checker=_errors._error_checker)
GL_INT_SAMPLER_2D_MULTISAMPLE=_C('GL_INT_SAMPLER_2D_MULTISAMPLE',0x9109)
GL_INT_SAMPLER_2D_MULTISAMPLE_ARRAY=_C('GL_INT_SAMPLER_2D_MULTISAMPLE_ARRAY',0x910C)
GL_MAX_COLOR_TEXTURE_SAMPLES=_C('GL_MAX_COLOR_TEXTURE_SAMPLES',0x910E)
GL_MAX_DEPTH_TEXTURE_SAMPLES=_C('GL_MAX_DEPTH_TEXTURE_SAMPLES',0x910F)
GL_MAX_INTEGER_SAMPLES=_C('GL_MAX_INTEGER_SAMPLES',0x9110)
GL_MAX_SAMPLE_MASK_WORDS=_C('GL_MAX_SAMPLE_MASK_WORDS',0x8E59)
GL_PROXY_TEXTURE_2D_MULTISAMPLE=_C('GL_PROXY_TEXTURE_2D_MULTISAMPLE',0x9101)
GL_PROXY_TEXTURE_2D_MULTISAMPLE_ARRAY=_C('GL_PROXY_TEXTURE_2D_MULTISAMPLE_ARRAY',0x9103)
GL_SAMPLER_2D_MULTISAMPLE=_C('GL_SAMPLER_2D_MULTISAMPLE',0x9108)
GL_SAMPLER_2D_MULTISAMPLE_ARRAY=_C('GL_SAMPLER_2D_MULTISAMPLE_ARRAY',0x910B)
GL_SAMPLE_MASK=_C('GL_SAMPLE_MASK',0x8E51)
GL_SAMPLE_MASK_VALUE=_C('GL_SAMPLE_MASK_VALUE',0x8E52)
GL_SAMPLE_POSITION=_C('GL_SAMPLE_POSITION',0x8E50)
GL_TEXTURE_2D_MULTISAMPLE=_C('GL_TEXTURE_2D_MULTISAMPLE',0x9100)
GL_TEXTURE_2D_MULTISAMPLE_ARRAY=_C('GL_TEXTURE_2D_MULTISAMPLE_ARRAY',0x9102)
GL_TEXTURE_BINDING_2D_MULTISAMPLE=_C('GL_TEXTURE_BINDING_2D_MULTISAMPLE',0x9104)
GL_TEXTURE_BINDING_2D_MULTISAMPLE_ARRAY=_C('GL_TEXTURE_BINDING_2D_MULTISAMPLE_ARRAY',0x9105)
GL_TEXTURE_FIXED_SAMPLE_LOCATIONS=_C('GL_TEXTURE_FIXED_SAMPLE_LOCATIONS',0x9107)
GL_TEXTURE_SAMPLES=_C('GL_TEXTURE_SAMPLES',0x9106)
GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE=_C('GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE',0x910A)
GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE_ARRAY=_C('GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE_ARRAY',0x910D)
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,arrays.GLfloatArray)
def glGetMultisamplefv(pname,index,val):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLbitfield)
def glSampleMaski(maskNumber,mask):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,_cs.GLenum,_cs.GLsizei,_cs.GLsizei,_cs.GLboolean)
def glTexImage2DMultisample(target,samples,internalformat,width,height,fixedsamplelocations):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,_cs.GLenum,_cs.GLsizei,_cs.GLsizei,_cs.GLsizei,_cs.GLboolean)
def glTexImage3DMultisample(target,samples,internalformat,width,height,depth,fixedsamplelocations):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_shader_storage_buffer_object'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_shader_storage_buffer_object',error_checker=_errors._error_checker)
GL_MAX_COMBINED_IMAGE_UNITS_AND_FRAGMENT_OUTPUTS=_C('GL_MAX_COMBINED_IMAGE_UNITS_AND_FRAGMENT_OUTPUTS',0x8F39)
GL_MAX_COMBINED_SHADER_OUTPUT_RESOURCES=_C('GL_MAX_COMBINED_SHADER_OUTPUT_RESOURCES',0x8F39)
GL_MAX_COMBINED_SHADER_STORAGE_BLOCKS=_C('GL_MAX_COMBINED_SHADER_STORAGE_BLOCKS',0x90DC)
GL_MAX_COMPUTE_SHADER_STORAGE_BLOCKS=_C('GL_MAX_COMPUTE_SHADER_STORAGE_BLOCKS',0x90DB)
GL_MAX_FRAGMENT_SHADER_STORAGE_BLOCKS=_C('GL_MAX_FRAGMENT_SHADER_STORAGE_BLOCKS',0x90DA)
GL_MAX_GEOMETRY_SHADER_STORAGE_BLOCKS=_C('GL_MAX_GEOMETRY_SHADER_STORAGE_BLOCKS',0x90D7)
GL_MAX_SHADER_STORAGE_BLOCK_SIZE=_C('GL_MAX_SHADER_STORAGE_BLOCK_SIZE',0x90DE)
GL_MAX_SHADER_STORAGE_BUFFER_BINDINGS=_C('GL_MAX_SHADER_STORAGE_BUFFER_BINDINGS',0x90DD)
GL_MAX_TESS_CONTROL_SHADER_STORAGE_BLOCKS=_C('GL_MAX_TESS_CONTROL_SHADER_STORAGE_BLOCKS',0x90D8)
GL_MAX_TESS_EVALUATION_SHADER_STORAGE_BLOCKS=_C('GL_MAX_TESS_EVALUATION_SHADER_STORAGE_BLOCKS',0x90D9)
GL_MAX_VERTEX_SHADER_STORAGE_BLOCKS=_C('GL_MAX_VERTEX_SHADER_STORAGE_BLOCKS',0x90D6)
GL_SHADER_STORAGE_BARRIER_BIT=_C('GL_SHADER_STORAGE_BARRIER_BIT',0x00002000)
GL_SHADER_STORAGE_BUFFER=_C('GL_SHADER_STORAGE_BUFFER',0x90D2)
GL_SHADER_STORAGE_BUFFER_BINDING=_C('GL_SHADER_STORAGE_BUFFER_BINDING',0x90D3)
GL_SHADER_STORAGE_BUFFER_OFFSET_ALIGNMENT=_C('GL_SHADER_STORAGE_BUFFER_OFFSET_ALIGNMENT',0x90DF)
GL_SHADER_STORAGE_BUFFER_SIZE=_C('GL_SHADER_STORAGE_BUFFER_SIZE',0x90D5)
GL_SHADER_STORAGE_BUFFER_START=_C('GL_SHADER_STORAGE_BUFFER_START',0x90D4)
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLuint)
def glShaderStorageBlockBinding(program,storageBlockIndex,storageBlockBinding):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_NV_depth_buffer_float'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_NV_depth_buffer_float',error_checker=_errors._error_checker)
GL_DEPTH32F_STENCIL8_NV=_C('GL_DEPTH32F_STENCIL8_NV',0x8DAC)
GL_DEPTH_BUFFER_FLOAT_MODE_NV=_C('GL_DEPTH_BUFFER_FLOAT_MODE_NV',0x8DAF)
GL_DEPTH_COMPONENT32F_NV=_C('GL_DEPTH_COMPONENT32F_NV',0x8DAB)
GL_FLOAT_32_UNSIGNED_INT_24_8_REV_NV=_C('GL_FLOAT_32_UNSIGNED_INT_24_8_REV_NV',0x8DAD)
@_f
@_p.types(None,_cs.GLdouble)
def glClearDepthdNV(depth):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble)
def glDepthBoundsdNV(zmin,zmax):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble)
def glDepthRangedNV(zNear,zFar):pass



'''OpenGL extension ARB.texture_env_add

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.texture_env_add to provide a more 
Python-friendly API

Overview (from the spec)
	
	New texture environment function ADD is supported with the following
	equation:
	                    Cv = min(1, Cf + Ct)
	
	New function may be specified by calling TexEnv with ADD token.
	
	One possible application is to add a specular highlight texture to
	a Gouraud-shaded primitive to emulate Phong shading, in a single
	pass.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/texture_env_add.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.texture_env_add import *
from OpenGL.raw.GL.ARB.texture_env_add import _EXTENSION_NAME

def glInitTextureEnvAddARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLX import _types as _cs
# End users want this...
from OpenGL.raw.GLX._types import *
from OpenGL.raw.GLX import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLX_MESA_set_3dfx_mode'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLX,'GLX_MESA_set_3dfx_mode',error_checker=_errors._error_checker)
GLX_3DFX_FULLSCREEN_MODE_MESA=_C('GLX_3DFX_FULLSCREEN_MODE_MESA',0x2)
GLX_3DFX_WINDOW_MODE_MESA=_C('GLX_3DFX_WINDOW_MODE_MESA',0x1)
@_f
@_p.types(_cs.Bool,_cs.c_int)
def glXSet3DfxModeMESA(mode):pass



'''OpenGL extension APPLE.vertex_program_evaluators

This module customises the behaviour of the 
OpenGL.raw.GL.APPLE.vertex_program_evaluators to provide a more 
Python-friendly API

Overview (from the spec)
	
	    This extension allows the one- and two-dimensional evaluators to be used
	    with vertex program attributes.  The operation of this extension is
	    precisely analogous to the operation of the normal evaluators.
	
		Where normal evaluators are enabled with Enable(MAP1_VERTEX_3), for
	    example, attribute evaluators are enabled with
	    EnableVertexAttribAPPLE(index, VERTEX_ATTRIB_MAP1_APPLE).
	
		Where the size (1, 2, 3, or 4) of a normal evaluator is embedded in the
	    token for that evaluator (for example, MAP1_VERTEX_3 has size 3),
	    attribute evaluators give the size as an argument to MapVertexAttrib**APPLE.
	
		The 1D and 2D evaluator order, domain, and coefficients are given as
	    arguments to MapVertexAttrib**APPLE, with exactly the same meaning and
	    restrictions as the same arguments to Map1f, Map2f, Map1d, & Map2d.
		The evaluator order, domain, and coefficients may be queried with
	    GetVertexAttrib*vARB, with the same operation as GetMap*v.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/APPLE/vertex_program_evaluators.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.APPLE.vertex_program_evaluators import *
from OpenGL.raw.GL.APPLE.vertex_program_evaluators import _EXTENSION_NAME

def glInitVertexProgramEvaluatorsAPPLE():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glMapVertexAttrib1dAPPLE.points size not checked against 'size,stride,order'
glMapVertexAttrib1dAPPLE=wrapper.wrapper(glMapVertexAttrib1dAPPLE).setInputArraySize(
    'points', None
)
# INPUT glMapVertexAttrib1fAPPLE.points size not checked against 'size,stride,order'
glMapVertexAttrib1fAPPLE=wrapper.wrapper(glMapVertexAttrib1fAPPLE).setInputArraySize(
    'points', None
)
# INPUT glMapVertexAttrib2dAPPLE.points size not checked against 'size,ustride,uorder,vstride,vorder'
glMapVertexAttrib2dAPPLE=wrapper.wrapper(glMapVertexAttrib2dAPPLE).setInputArraySize(
    'points', None
)
# INPUT glMapVertexAttrib2fAPPLE.points size not checked against 'size,ustride,uorder,vstride,vorder'
glMapVertexAttrib2fAPPLE=wrapper.wrapper(glMapVertexAttrib2fAPPLE).setInputArraySize(
    'points', None
)
### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_NV_vertex_attrib_integer_64bit'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_NV_vertex_attrib_integer_64bit',error_checker=_errors._error_checker)
GL_INT64_NV=_C('GL_INT64_NV',0x140E)
GL_UNSIGNED_INT64_NV=_C('GL_UNSIGNED_INT64_NV',0x140F)
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLint64Array)
def glGetVertexAttribLi64vNV(index,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLuint64Array)
def glGetVertexAttribLui64vNV(index,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint64EXT)
def glVertexAttribL1i64NV(index,x):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLint64Array)
def glVertexAttribL1i64vNV(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint64EXT)
def glVertexAttribL1ui64NV(index,x):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLuint64Array)
def glVertexAttribL1ui64vNV(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint64EXT,_cs.GLint64EXT)
def glVertexAttribL2i64NV(index,x,y):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLint64Array)
def glVertexAttribL2i64vNV(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint64EXT,_cs.GLuint64EXT)
def glVertexAttribL2ui64NV(index,x,y):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLuint64Array)
def glVertexAttribL2ui64vNV(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint64EXT,_cs.GLint64EXT,_cs.GLint64EXT)
def glVertexAttribL3i64NV(index,x,y,z):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLint64Array)
def glVertexAttribL3i64vNV(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint64EXT,_cs.GLuint64EXT,_cs.GLuint64EXT)
def glVertexAttribL3ui64NV(index,x,y,z):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLuint64Array)
def glVertexAttribL3ui64vNV(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint64EXT,_cs.GLint64EXT,_cs.GLint64EXT,_cs.GLint64EXT)
def glVertexAttribL4i64NV(index,x,y,z,w):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLint64Array)
def glVertexAttribL4i64vNV(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint64EXT,_cs.GLuint64EXT,_cs.GLuint64EXT,_cs.GLuint64EXT)
def glVertexAttribL4ui64NV(index,x,y,z,w):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLuint64Array)
def glVertexAttribL4ui64vNV(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLenum,_cs.GLsizei)
def glVertexAttribLFormatNV(index,size,type,stride):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_sync'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_sync',error_checker=_errors._error_checker)
GL_ALREADY_SIGNALED=_C('GL_ALREADY_SIGNALED',0x911A)
GL_CONDITION_SATISFIED=_C('GL_CONDITION_SATISFIED',0x911C)
GL_MAX_SERVER_WAIT_TIMEOUT=_C('GL_MAX_SERVER_WAIT_TIMEOUT',0x9111)
GL_OBJECT_TYPE=_C('GL_OBJECT_TYPE',0x9112)
GL_SIGNALED=_C('GL_SIGNALED',0x9119)
GL_SYNC_CONDITION=_C('GL_SYNC_CONDITION',0x9113)
GL_SYNC_FENCE=_C('GL_SYNC_FENCE',0x9116)
GL_SYNC_FLAGS=_C('GL_SYNC_FLAGS',0x9115)
GL_SYNC_FLUSH_COMMANDS_BIT=_C('GL_SYNC_FLUSH_COMMANDS_BIT',0x00000001)
GL_SYNC_GPU_COMMANDS_COMPLETE=_C('GL_SYNC_GPU_COMMANDS_COMPLETE',0x9117)
GL_SYNC_STATUS=_C('GL_SYNC_STATUS',0x9114)
GL_TIMEOUT_EXPIRED=_C('GL_TIMEOUT_EXPIRED',0x911B)
GL_TIMEOUT_IGNORED=_C('GL_TIMEOUT_IGNORED',0xFFFFFFFFFFFFFFFF)
GL_UNSIGNALED=_C('GL_UNSIGNALED',0x9118)
GL_WAIT_FAILED=_C('GL_WAIT_FAILED',0x911D)
@_f
@_p.types(_cs.GLenum,_cs.GLsync,_cs.GLbitfield,_cs.GLuint64)
def glClientWaitSync(sync,flags,timeout):pass
@_f
@_p.types(None,_cs.GLsync)
def glDeleteSync(sync):pass
@_f
@_p.types(_cs.GLsync,_cs.GLenum,_cs.GLbitfield)
def glFenceSync(condition,flags):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLint64Array)
def glGetInteger64v(pname,data):pass
@_f
@_p.types(None,_cs.GLsync,_cs.GLenum,_cs.GLsizei,arrays.GLsizeiArray,arrays.GLintArray)
def glGetSynciv(sync,pname,bufSize,length,values):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLsync)
def glIsSync(sync):pass
@_f
@_p.types(None,_cs.GLsync,_cs.GLbitfield,_cs.GLuint64)
def glWaitSync(sync,flags,timeout):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_INTEL_map_texture'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_INTEL_map_texture',error_checker=_errors._error_checker)
GL_LAYOUT_DEFAULT_INTEL=_C('GL_LAYOUT_DEFAULT_INTEL',0)
GL_LAYOUT_LINEAR_CPU_CACHED_INTEL=_C('GL_LAYOUT_LINEAR_CPU_CACHED_INTEL',2)
GL_LAYOUT_LINEAR_INTEL=_C('GL_LAYOUT_LINEAR_INTEL',1)
GL_TEXTURE_MEMORY_LAYOUT_INTEL=_C('GL_TEXTURE_MEMORY_LAYOUT_INTEL',0x83FF)
@_f
@_p.types(ctypes.c_void_p,_cs.GLuint,_cs.GLint,_cs.GLbitfield,arrays.GLintArray,arrays.GLuintArray)
def glMapTexture2DINTEL(texture,level,access,stride,layout):pass
@_f
@_p.types(None,_cs.GLuint)
def glSyncTextureINTEL(texture):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint)
def glUnmapTexture2DINTEL(texture,level):pass



'''OpenGL extension OML.resample

This module customises the behaviour of the 
OpenGL.raw.GL.OML.resample to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension enhances the resampling capabilities of the
	OML_subsample extension. It is loosely based on the SGIX_resample
	extension.
	
	When converting data from subsampled to uniform sampling, upsampling
	may be performed by one of three methods: component replication,
	zero fill, or adjacent neighbor averaging.
	
	When converting data from uniform sampling to subsampled form,
	downsampling may be performed only by component decimation (point
	sampling) or averaging.
	
	Upsampling and downsampling filters other than those defined by this
	extension may be performed by appropriate use of convolution and
	other pixel transfer operations. The zero fill unpacking mode is
	included to assist applications wanting to define their own filters.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/OML/resample.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.OML.resample import *
from OpenGL.raw.GL.OML.resample import _EXTENSION_NAME

def glInitResampleOML():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_vertex_buffer_object'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_vertex_buffer_object',error_checker=_errors._error_checker)
GL_ARRAY_BUFFER_ARB=_C('GL_ARRAY_BUFFER_ARB',0x8892)
GL_ARRAY_BUFFER_BINDING_ARB=_C('GL_ARRAY_BUFFER_BINDING_ARB',0x8894)
GL_BUFFER_ACCESS_ARB=_C('GL_BUFFER_ACCESS_ARB',0x88BB)
GL_BUFFER_MAPPED_ARB=_C('GL_BUFFER_MAPPED_ARB',0x88BC)
GL_BUFFER_MAP_POINTER_ARB=_C('GL_BUFFER_MAP_POINTER_ARB',0x88BD)
GL_BUFFER_SIZE_ARB=_C('GL_BUFFER_SIZE_ARB',0x8764)
GL_BUFFER_USAGE_ARB=_C('GL_BUFFER_USAGE_ARB',0x8765)
GL_COLOR_ARRAY_BUFFER_BINDING_ARB=_C('GL_COLOR_ARRAY_BUFFER_BINDING_ARB',0x8898)
GL_DYNAMIC_COPY_ARB=_C('GL_DYNAMIC_COPY_ARB',0x88EA)
GL_DYNAMIC_DRAW_ARB=_C('GL_DYNAMIC_DRAW_ARB',0x88E8)
GL_DYNAMIC_READ_ARB=_C('GL_DYNAMIC_READ_ARB',0x88E9)
GL_EDGE_FLAG_ARRAY_BUFFER_BINDING_ARB=_C('GL_EDGE_FLAG_ARRAY_BUFFER_BINDING_ARB',0x889B)
GL_ELEMENT_ARRAY_BUFFER_ARB=_C('GL_ELEMENT_ARRAY_BUFFER_ARB',0x8893)
GL_ELEMENT_ARRAY_BUFFER_BINDING_ARB=_C('GL_ELEMENT_ARRAY_BUFFER_BINDING_ARB',0x8895)
GL_FOG_COORDINATE_ARRAY_BUFFER_BINDING_ARB=_C('GL_FOG_COORDINATE_ARRAY_BUFFER_BINDING_ARB',0x889D)
GL_INDEX_ARRAY_BUFFER_BINDING_ARB=_C('GL_INDEX_ARRAY_BUFFER_BINDING_ARB',0x8899)
GL_NORMAL_ARRAY_BUFFER_BINDING_ARB=_C('GL_NORMAL_ARRAY_BUFFER_BINDING_ARB',0x8897)
GL_READ_ONLY_ARB=_C('GL_READ_ONLY_ARB',0x88B8)
GL_READ_WRITE_ARB=_C('GL_READ_WRITE_ARB',0x88BA)
GL_SECONDARY_COLOR_ARRAY_BUFFER_BINDING_ARB=_C('GL_SECONDARY_COLOR_ARRAY_BUFFER_BINDING_ARB',0x889C)
GL_STATIC_COPY_ARB=_C('GL_STATIC_COPY_ARB',0x88E6)
GL_STATIC_DRAW_ARB=_C('GL_STATIC_DRAW_ARB',0x88E4)
GL_STATIC_READ_ARB=_C('GL_STATIC_READ_ARB',0x88E5)
GL_STREAM_COPY_ARB=_C('GL_STREAM_COPY_ARB',0x88E2)
GL_STREAM_DRAW_ARB=_C('GL_STREAM_DRAW_ARB',0x88E0)
GL_STREAM_READ_ARB=_C('GL_STREAM_READ_ARB',0x88E1)
GL_TEXTURE_COORD_ARRAY_BUFFER_BINDING_ARB=_C('GL_TEXTURE_COORD_ARRAY_BUFFER_BINDING_ARB',0x889A)
GL_VERTEX_ARRAY_BUFFER_BINDING_ARB=_C('GL_VERTEX_ARRAY_BUFFER_BINDING_ARB',0x8896)
GL_VERTEX_ATTRIB_ARRAY_BUFFER_BINDING_ARB=_C('GL_VERTEX_ATTRIB_ARRAY_BUFFER_BINDING_ARB',0x889F)
GL_WEIGHT_ARRAY_BUFFER_BINDING_ARB=_C('GL_WEIGHT_ARRAY_BUFFER_BINDING_ARB',0x889E)
GL_WRITE_ONLY_ARB=_C('GL_WRITE_ONLY_ARB',0x88B9)
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glBindBufferARB(target,buffer):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizeiptrARB,ctypes.c_void_p,_cs.GLenum)
def glBufferDataARB(target,size,data,usage):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLintptrARB,_cs.GLsizeiptrARB,ctypes.c_void_p)
def glBufferSubDataARB(target,offset,size,data):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glDeleteBuffersARB(n,buffers):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glGenBuffersARB(n,buffers):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetBufferParameterivARB(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLvoidpArray)
def glGetBufferPointervARB(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLintptrARB,_cs.GLsizeiptrARB,ctypes.c_void_p)
def glGetBufferSubDataARB(target,offset,size,data):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLuint)
def glIsBufferARB(buffer):pass
@_f
@_p.types(ctypes.c_void_p,_cs.GLenum,_cs.GLenum)
def glMapBufferARB(target,access):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLenum)
def glUnmapBufferARB(target):pass



'''OpenGL extension ARB.clear_texture

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.clear_texture to provide a more 
Python-friendly API

Overview (from the spec)
	
	Texture objects are fundamental to the operation of OpenGL. They are
	used as a source for texture sampling and destination for rendering
	as well as being accessed in shaders for image load/store operations
	It is also possible to invalidate the contents of a texture. It is
	currently only possible to set texture image data to known values by
	uploading some or all of a image array from application memory or by
	attaching it to a framebuffer object and using the Clear or ClearBuffer
	commands.
	
	Both uploading initial texture data and clearing by attaching to a
	framebuffer have potential disadvantages when one simply wants to
	initialize texture data to a known value. Uploading initial data
	requires the application to allocate a (potentially large) chunk
	of memory and transferring that to the GL.  This can be a costly
	operation both in terms of memory bandwidth and power usage.
	Alternatively, attaching a texture level to a framebuffer to clear it
	may not be possible if the texture format isn't supported for
	rendering, or even if it is, attaching the image to a framebuffer object
	may cause the texture to be allocated in certain types of memory, which
	it may otherwise not need to be placed in.
	
	This extension solves these problems by providing a mechanism whereby
	the contents of a texture image array can be set to known values by
	using the ClearTexImage or ClearTexSubImage commands.  These commands
	can also be useful for initializing an image that will be used for
	atomic shader operations.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/clear_texture.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.clear_texture import *
from OpenGL.raw.GL.ARB.clear_texture import _EXTENSION_NAME

def glInitClearTextureARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glClearTexImage.data size not checked against 'format,type'
glClearTexImage=wrapper.wrapper(glClearTexImage).setInputArraySize(
    'data', None
)
# INPUT glClearTexSubImage.data size not checked against 'format,type'
glClearTexSubImage=wrapper.wrapper(glClearTexSubImage).setInputArraySize(
    'data', None
)
### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_AMD_debug_output'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_AMD_debug_output',error_checker=_errors._error_checker)
GL_DEBUG_CATEGORY_API_ERROR_AMD=_C('GL_DEBUG_CATEGORY_API_ERROR_AMD',0x9149)
GL_DEBUG_CATEGORY_APPLICATION_AMD=_C('GL_DEBUG_CATEGORY_APPLICATION_AMD',0x914F)
GL_DEBUG_CATEGORY_DEPRECATION_AMD=_C('GL_DEBUG_CATEGORY_DEPRECATION_AMD',0x914B)
GL_DEBUG_CATEGORY_OTHER_AMD=_C('GL_DEBUG_CATEGORY_OTHER_AMD',0x9150)
GL_DEBUG_CATEGORY_PERFORMANCE_AMD=_C('GL_DEBUG_CATEGORY_PERFORMANCE_AMD',0x914D)
GL_DEBUG_CATEGORY_SHADER_COMPILER_AMD=_C('GL_DEBUG_CATEGORY_SHADER_COMPILER_AMD',0x914E)
GL_DEBUG_CATEGORY_UNDEFINED_BEHAVIOR_AMD=_C('GL_DEBUG_CATEGORY_UNDEFINED_BEHAVIOR_AMD',0x914C)
GL_DEBUG_CATEGORY_WINDOW_SYSTEM_AMD=_C('GL_DEBUG_CATEGORY_WINDOW_SYSTEM_AMD',0x914A)
GL_DEBUG_LOGGED_MESSAGES_AMD=_C('GL_DEBUG_LOGGED_MESSAGES_AMD',0x9145)
GL_DEBUG_SEVERITY_HIGH_AMD=_C('GL_DEBUG_SEVERITY_HIGH_AMD',0x9146)
GL_DEBUG_SEVERITY_LOW_AMD=_C('GL_DEBUG_SEVERITY_LOW_AMD',0x9148)
GL_DEBUG_SEVERITY_MEDIUM_AMD=_C('GL_DEBUG_SEVERITY_MEDIUM_AMD',0x9147)
GL_MAX_DEBUG_LOGGED_MESSAGES_AMD=_C('GL_MAX_DEBUG_LOGGED_MESSAGES_AMD',0x9144)
GL_MAX_DEBUG_MESSAGE_LENGTH_AMD=_C('GL_MAX_DEBUG_MESSAGE_LENGTH_AMD',0x9143)
@_f
@_p.types(None,_cs.GLDEBUGPROCAMD,ctypes.c_void_p)
def glDebugMessageCallbackAMD(callback,userParam):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLsizei,arrays.GLuintArray,_cs.GLboolean)
def glDebugMessageEnableAMD(category,severity,count,ids,enabled):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLuint,_cs.GLsizei,arrays.GLcharArray)
def glDebugMessageInsertAMD(category,severity,id,length,buf):pass
@_f
@_p.types(_cs.GLuint,_cs.GLuint,_cs.GLsizei,arrays.GLuintArray,arrays.GLuintArray,arrays.GLuintArray,arrays.GLsizeiArray,arrays.GLcharArray)
def glGetDebugMessageLogAMD(count,bufsize,categories,severities,ids,lengths,message):pass



'''OpenGL extension ARB.vertex_array_bgra

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.vertex_array_bgra to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a single new component format for vertex
	arrays to read 4-component unsigned byte vertex attributes with a
	BGRA component ordering.
	
	OpenGL expects vertex arrays containing 4 unsigned bytes per
	element to be in the RGBA, STRQ, or XYZW order (reading components
	left-to-right in their lower address to higher address order).
	Essentially the order the components appear in memory is the order
	the components appear in the resulting vertex attribute vector.
	
	However Direct3D has color (diffuse and specular) vertex arrays
	containing 4 unsigned bytes per element that are in a BGRA order
	(again reading components left-to-right in their lower address
	to higher address order).  Direct3D calls this "ARGB" reading the
	components in the opposite order (reading components left-to-right
	in their higher address to lower address order).  This ordering is
	generalized in the DirectX 10 by the DXGI_FORMAT_B8G8R8A8_UNORM
	format.
	
	For an OpenGL application to source color data from a vertex
	buffer formatted for Direct3D's color array format conventions,
	the application is forced to either:
	
	1.  Rely on a vertex program or shader to swizzle the color components
	    from the BGRA to conventional RGBA order.
	
	2.  Re-order the color data components in the vertex buffer from
	    Direct3D's native BGRA order to OpenGL's native RGBA order.
	
	Neither option is entirely satisfactory.
	
	Option 1 means vertex shaders have to be re-written to source colors
	differently.  If the same vertex shader is used with vertex arrays
	configured to source the color as 4 floating-point color components,
	the swizzle for BGRA colors stored as 4 unsigned bytes is no longer
	appropriate.  The shader's swizzling of colors becomes dependent on
	the type and number of color components.  Ideally the vertex shader
	should be independent from the format and component ordering of the
	data it sources.
	
	Option 2 is expensive because vertex buffers may have to be
	reformatted prior to use.  OpenGL treats the memory for vertex arrays
	(whether client-side memory or buffer objects) as essentially untyped
	memory and vertex arrays can be stored separately, interleaved,
	or even interwoven (where multiple arrays overlap with differing
	strides and formats).
	
	Rather than force a re-ordering of either vertex array components
	in memory or a vertex array format-dependent re-ordering of vertex
	shader inputs, OpenGL can simply provide a vertex array format that
	matches the Direct3D color component ordering.
	
	This approach mimics that of the EXT_bgra extension for pixel and
	texel formats except for vertex instead of image data.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/vertex_array_bgra.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.vertex_array_bgra import *
from OpenGL.raw.GL.ARB.vertex_array_bgra import _EXTENSION_NAME

def glInitVertexArrayBgraARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension NV.texture_barrier

This module customises the behaviour of the 
OpenGL.raw.GL.NV.texture_barrier to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension relaxes the restrictions on rendering to a currently
	bound texture and provides a mechanism to avoid read-after-write
	hazards.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/texture_barrier.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.texture_barrier import *
from OpenGL.raw.GL.NV.texture_barrier import _EXTENSION_NAME

def glInitTextureBarrierNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''GLU extension EXT.nurbs_tessellator
'''
from OpenGL import extensions
from OpenGL.raw.GLU import constants

GLU_NURBS_BEGIN_EXT = _types.GLU_NURBS_BEGIN_EXT
GLU_NURBS_VERTEX_EXT = _types.GLU_NURBS_VERTEX_EXT
GLU_NURBS_COLOR_EXT = _types.GLU_NURBS_COLOR_EXT
GLU_NURBS_TEX_COORD_EXT = _types.GLU_NURBS_TEX_COORD_EXT
GLU_NURBS_END_EXT = _types.GLU_NURBS_END_EXT
GLU_NURBS_BEGIN_DATA_EXT = _types.GLU_NURBS_BEGIN_DATA_EXT
GLU_NURBS_VERTEX_DATA_EXT = _types.GLU_NURBS_VERTEX_DATA_EXT
GLU_NURBS_NORMAL_DATA_EXT = _types.GLU_NURBS_NORMAL_DATA_EXT
GLU_NURBS_COLOR_DATA_EXT = _types.GLU_NURBS_COLOR_DATA_EXT
GLU_NURBS_TEX_COORD_DATA_EXT = _types.GLU_NURBS_TEX_COORD_DATA_EXT
GLU_NURBS_END_DATA_EXT = _types.GLU_NURBS_END_DATA_EXT
GLU_NURBS_MODE_EXT = _types.GLU_NURBS_MODE_EXT
GLU_NURBS_TESSELLATOR_EXT = _types.GLU_NURBS_TESSELLATOR_EXT
GLU_NURBS_RENDERER_EXT = _types.GLU_NURBS_RENDERER_EXT

def gluInitNurbsTessellatorEXT():
    '''Return boolean indicating whether this module is available'''
    return extensions.hasGLUExtension( 'GLU_EXT_nurbs_tessellator' )


'''OpenGL extension ARB.texture_non_power_of_two

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.texture_non_power_of_two to provide a more 
Python-friendly API

Overview (from the spec)
	
	Conventional OpenGL texturing is limited to images with
	power-of-two dimensions and an optional 1-texel border.
	ARB_texture_non_power_of_two extension relaxes the size restrictions
	for the 1D, 2D, cube map, and 3D texture targets.
	
	There is no additional procedural or enumerant api introduced by this
	extension except that an implementation which exports the extension
	string will allow an application to pass in texture dimensions for
	the 1D, 2D, cube map, and 3D targets that may or may not be a power
	of two.
	
	An implementation which supports relaxing traditional GL's
	power-of-two size restrictions across all texture targets will export
	the extension string: "ARB_texture_non_power_of_two".
	
	When this extension is supported, mipmapping, automatic mipmap
	generation, and all the conventional wrap modes are supported for
	non-power-of-two textures

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/texture_non_power_of_two.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.texture_non_power_of_two import *
from OpenGL.raw.GL.ARB.texture_non_power_of_two import _EXTENSION_NAME

def glInitTextureNonPowerOfTwoARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension ARB.provoking_vertex

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.provoking_vertex to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides an alternative provoking vertex convention
	for rendering lines, triangles, and (optionally depending on the
	implementation) quads.
	
	The provoking vertex of a primitive is the vertex that determines the
	constant primary and secondary colors when flat shading is enabled.
	
	In OpenGL, the provoking vertex for triangle, quad, line, and
	(trivially) point primitives is the last vertex used to assemble
	the primitive.  The polygon primitive is an exception in OpenGL where
	the first vertex of a polygon primitive determines the color of the
	polygon, even if actually broken into triangles and/or quads.
	
	See section 2.14.7 (Flatshading) of the OpenGL 2.1 specification,
	particularly Table 2.12 for more details.
	
	Alternatively the provoking vertex could be the first vertex of
	the primitive.  Other APIs with flat-shading functionality such
	as Reality Lab and Direct3D have adopted the "first vertex of the
	primitive" convention to determine the provoking vertex.  However,
	these APIs lack quads so do not have a defined provoking vertex
	convention for quads.
	
	The motivation for this extension is to allow applications developed
	for APIs with a "first vertex of the primitive" provoking vertex to
	be easily converted to OpenGL.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/provoking_vertex.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.provoking_vertex import *
from OpenGL.raw.GL.ARB.provoking_vertex import _EXTENSION_NAME

def glInitProvokingVertexARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension NV.viewport_array

This module customises the behaviour of the 
OpenGL.raw.GLES2.NV.viewport_array to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/viewport_array.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.NV.viewport_array import *
from OpenGL.raw.GLES2.NV.viewport_array import _EXTENSION_NAME

def glInitViewportArrayNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glViewportArrayvNV.v size not checked against 'count'
glViewportArrayvNV=wrapper.wrapper(glViewportArrayvNV).setInputArraySize(
    'v', None
)
glViewportIndexedfvNV=wrapper.wrapper(glViewportIndexedfvNV).setInputArraySize(
    'v', 4
)
# INPUT glScissorArrayvNV.v size not checked against 'count'
glScissorArrayvNV=wrapper.wrapper(glScissorArrayvNV).setInputArraySize(
    'v', None
)
glScissorIndexedvNV=wrapper.wrapper(glScissorIndexedvNV).setInputArraySize(
    'v', 4
)
# INPUT glGetFloati_vNV.data size not checked against 'target'
glGetFloati_vNV=wrapper.wrapper(glGetFloati_vNV).setInputArraySize(
    'data', None
)
### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.EGL import _types as _cs
# End users want this...
from OpenGL.raw.EGL._types import *
from OpenGL.raw.EGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'EGL_VERSION_EGL_1_2'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.EGL,'EGL_VERSION_EGL_1_2',error_checker=_errors._error_checker)
EGL_ALPHA_FORMAT=_C('EGL_ALPHA_FORMAT',0x3088)
EGL_ALPHA_FORMAT_NONPRE=_C('EGL_ALPHA_FORMAT_NONPRE',0x308B)
EGL_ALPHA_FORMAT_PRE=_C('EGL_ALPHA_FORMAT_PRE',0x308C)
EGL_ALPHA_MASK_SIZE=_C('EGL_ALPHA_MASK_SIZE',0x303E)
EGL_BUFFER_DESTROYED=_C('EGL_BUFFER_DESTROYED',0x3095)
EGL_BUFFER_PRESERVED=_C('EGL_BUFFER_PRESERVED',0x3094)
EGL_CLIENT_APIS=_C('EGL_CLIENT_APIS',0x308D)
EGL_COLORSPACE=_C('EGL_COLORSPACE',0x3087)
EGL_COLORSPACE_LINEAR=_C('EGL_COLORSPACE_LINEAR',0x308A)
EGL_COLORSPACE_sRGB=_C('EGL_COLORSPACE_sRGB',0x3089)
EGL_COLOR_BUFFER_TYPE=_C('EGL_COLOR_BUFFER_TYPE',0x303F)
EGL_CONTEXT_CLIENT_TYPE=_C('EGL_CONTEXT_CLIENT_TYPE',0x3097)
EGL_DISPLAY_SCALING=_C('EGL_DISPLAY_SCALING',10000)
EGL_HORIZONTAL_RESOLUTION=_C('EGL_HORIZONTAL_RESOLUTION',0x3090)
EGL_LUMINANCE_BUFFER=_C('EGL_LUMINANCE_BUFFER',0x308F)
EGL_LUMINANCE_SIZE=_C('EGL_LUMINANCE_SIZE',0x303D)
EGL_OPENGL_ES_API=_C('EGL_OPENGL_ES_API',0x30A0)
EGL_OPENGL_ES_BIT=_C('EGL_OPENGL_ES_BIT',0x0001)
EGL_OPENVG_API=_C('EGL_OPENVG_API',0x30A1)
EGL_OPENVG_BIT=_C('EGL_OPENVG_BIT',0x0002)
EGL_OPENVG_IMAGE=_C('EGL_OPENVG_IMAGE',0x3096)
EGL_PIXEL_ASPECT_RATIO=_C('EGL_PIXEL_ASPECT_RATIO',0x3092)
EGL_RENDERABLE_TYPE=_C('EGL_RENDERABLE_TYPE',0x3040)
EGL_RENDER_BUFFER=_C('EGL_RENDER_BUFFER',0x3086)
EGL_RGB_BUFFER=_C('EGL_RGB_BUFFER',0x308E)
EGL_SINGLE_BUFFER=_C('EGL_SINGLE_BUFFER',0x3085)
EGL_SWAP_BEHAVIOR=_C('EGL_SWAP_BEHAVIOR',0x3093)
# EGL_UNKNOWN=_C('EGL_UNKNOWN',((EGLint)-1))
EGL_VERTICAL_RESOLUTION=_C('EGL_VERTICAL_RESOLUTION',0x3091)
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLenum)
def eglBindAPI(api):pass
@_f
@_p.types(_cs.EGLSurface,_cs.EGLDisplay,_cs.EGLenum,_cs.EGLClientBuffer,_cs.EGLConfig,arrays.GLintArray)
def eglCreatePbufferFromClientBuffer(dpy,buftype,buffer,config,attrib_list):pass
@_f
@_p.types(_cs.EGLenum,)
def eglQueryAPI():pass
@_f
@_p.types(_cs.EGLBoolean,)
def eglReleaseThread():pass
@_f
@_p.types(_cs.EGLBoolean,)
def eglWaitClient():pass



'''OpenGL extension EXT.draw_instanced

This module customises the behaviour of the 
OpenGL.raw.GLES2.EXT.draw_instanced to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides the means to render multiple instances of
	an object with a single draw call, and an "instance ID" variable
	which can be used by the vertex program to compute per-instance
	values, typically an object's transform.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/draw_instanced.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.EXT.draw_instanced import *
from OpenGL.raw.GLES2.EXT.draw_instanced import _EXTENSION_NAME

def glInitDrawInstancedEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glDrawElementsInstancedEXT.indices size not checked against 'count,type'
glDrawElementsInstancedEXT=wrapper.wrapper(glDrawElementsInstancedEXT).setInputArraySize(
    'indices', None
)
### END AUTOGENERATED SECTION


'''OpenGL extension ARB.ES3_1_compatibility

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.ES3_1_compatibility to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension adds support for features of OpenGL ES 3.1 that are
	missing from OpenGL 4.4. Enabling these features will ease the process
	of porting applications from OpenGL ES 3.1 to OpenGL.
	
	In particular this adds the following features:
	
	- a new MemoryBarrierByRegion API which is potentially more efficient
	for specific localized memory access patterns.
	
	- increases the minimum required size of SSBOs to 2^27 (128 MB).
	
	- support for GLSL ES version 310 (ie #version 310 es).
	
	- a new GLSL built-in function, imageAtomicExchange, which performs atomic
	exchanges on r32f floating point images.
	
	- a new GLSL built-in fragment shader input, gl_HelperInvocation, that
	identifies whether the current fragment shader input is a helper
	invocation.  Fragment shader code can use this variable to skip performing
	operations that are useless or potentially dangerous for helper
	invocations.
	
	- a new GLSL built-in constant for the maximum supported samples:
	gl_MaxSamples.
	
	- a number of new GLSL built-in constants mirroring the API limits for
	image uniforms: gl_Max*ImageUniforms, gl_MaxCombinedShaderOutputResources.
	
	- new GLSL built-in functions which extend mix() to select between int,
	uint, and bool components.
	
	- add the "coherent" qualifier to all memory variables taken by the GLSL
	built-in atomic* and imageAtomic* functions.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/ES3_1_compatibility.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.ES3_1_compatibility import *
from OpenGL.raw.GL.ARB.ES3_1_compatibility import _EXTENSION_NAME

def glInitEs31CompatibilityARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_shader_objects'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_shader_objects',error_checker=_errors._error_checker)
GL_BOOL_ARB=_C('GL_BOOL_ARB',0x8B56)
GL_BOOL_VEC2_ARB=_C('GL_BOOL_VEC2_ARB',0x8B57)
GL_BOOL_VEC3_ARB=_C('GL_BOOL_VEC3_ARB',0x8B58)
GL_BOOL_VEC4_ARB=_C('GL_BOOL_VEC4_ARB',0x8B59)
GL_FLOAT_MAT2_ARB=_C('GL_FLOAT_MAT2_ARB',0x8B5A)
GL_FLOAT_MAT3_ARB=_C('GL_FLOAT_MAT3_ARB',0x8B5B)
GL_FLOAT_MAT4_ARB=_C('GL_FLOAT_MAT4_ARB',0x8B5C)
GL_FLOAT_VEC2_ARB=_C('GL_FLOAT_VEC2_ARB',0x8B50)
GL_FLOAT_VEC3_ARB=_C('GL_FLOAT_VEC3_ARB',0x8B51)
GL_FLOAT_VEC4_ARB=_C('GL_FLOAT_VEC4_ARB',0x8B52)
GL_INT_VEC2_ARB=_C('GL_INT_VEC2_ARB',0x8B53)
GL_INT_VEC3_ARB=_C('GL_INT_VEC3_ARB',0x8B54)
GL_INT_VEC4_ARB=_C('GL_INT_VEC4_ARB',0x8B55)
GL_OBJECT_ACTIVE_UNIFORMS_ARB=_C('GL_OBJECT_ACTIVE_UNIFORMS_ARB',0x8B86)
GL_OBJECT_ACTIVE_UNIFORM_MAX_LENGTH_ARB=_C('GL_OBJECT_ACTIVE_UNIFORM_MAX_LENGTH_ARB',0x8B87)
GL_OBJECT_ATTACHED_OBJECTS_ARB=_C('GL_OBJECT_ATTACHED_OBJECTS_ARB',0x8B85)
GL_OBJECT_COMPILE_STATUS_ARB=_C('GL_OBJECT_COMPILE_STATUS_ARB',0x8B81)
GL_OBJECT_DELETE_STATUS_ARB=_C('GL_OBJECT_DELETE_STATUS_ARB',0x8B80)
GL_OBJECT_INFO_LOG_LENGTH_ARB=_C('GL_OBJECT_INFO_LOG_LENGTH_ARB',0x8B84)
GL_OBJECT_LINK_STATUS_ARB=_C('GL_OBJECT_LINK_STATUS_ARB',0x8B82)
GL_OBJECT_SHADER_SOURCE_LENGTH_ARB=_C('GL_OBJECT_SHADER_SOURCE_LENGTH_ARB',0x8B88)
GL_OBJECT_SUBTYPE_ARB=_C('GL_OBJECT_SUBTYPE_ARB',0x8B4F)
GL_OBJECT_TYPE_ARB=_C('GL_OBJECT_TYPE_ARB',0x8B4E)
GL_OBJECT_VALIDATE_STATUS_ARB=_C('GL_OBJECT_VALIDATE_STATUS_ARB',0x8B83)
GL_PROGRAM_OBJECT_ARB=_C('GL_PROGRAM_OBJECT_ARB',0x8B40)
GL_SAMPLER_1D_ARB=_C('GL_SAMPLER_1D_ARB',0x8B5D)
GL_SAMPLER_1D_SHADOW_ARB=_C('GL_SAMPLER_1D_SHADOW_ARB',0x8B61)
GL_SAMPLER_2D_ARB=_C('GL_SAMPLER_2D_ARB',0x8B5E)
GL_SAMPLER_2D_RECT_ARB=_C('GL_SAMPLER_2D_RECT_ARB',0x8B63)
GL_SAMPLER_2D_RECT_SHADOW_ARB=_C('GL_SAMPLER_2D_RECT_SHADOW_ARB',0x8B64)
GL_SAMPLER_2D_SHADOW_ARB=_C('GL_SAMPLER_2D_SHADOW_ARB',0x8B62)
GL_SAMPLER_3D_ARB=_C('GL_SAMPLER_3D_ARB',0x8B5F)
GL_SAMPLER_CUBE_ARB=_C('GL_SAMPLER_CUBE_ARB',0x8B60)
GL_SHADER_OBJECT_ARB=_C('GL_SHADER_OBJECT_ARB',0x8B48)
@_f
@_p.types(None,_cs.GLhandleARB,_cs.GLhandleARB)
def glAttachObjectARB(containerObj,obj):pass
@_f
@_p.types(None,_cs.GLhandleARB)
def glCompileShaderARB(shaderObj):pass
@_f
@_p.types(_cs.GLhandleARB,)
def glCreateProgramObjectARB():pass
@_f
@_p.types(_cs.GLhandleARB,_cs.GLenum)
def glCreateShaderObjectARB(shaderType):pass
@_f
@_p.types(None,_cs.GLhandleARB)
def glDeleteObjectARB(obj):pass
@_f
@_p.types(None,_cs.GLhandleARB,_cs.GLhandleARB)
def glDetachObjectARB(containerObj,attachedObj):pass
@_f
@_p.types(None,_cs.GLhandleARB,_cs.GLuint,_cs.GLsizei,arrays.GLsizeiArray,arrays.GLintArray,arrays.GLuintArray,arrays.GLcharARBArray)
def glGetActiveUniformARB(programObj,index,maxLength,length,size,type,name):pass
@_f
@_p.types(None,_cs.GLhandleARB,_cs.GLsizei,arrays.GLsizeiArray,arrays.GLuintArray)
def glGetAttachedObjectsARB(containerObj,maxCount,count,obj):pass
@_f
@_p.types(_cs.GLhandleARB,_cs.GLenum)
def glGetHandleARB(pname):pass
@_f
@_p.types(None,_cs.GLhandleARB,_cs.GLsizei,arrays.GLsizeiArray,arrays.GLcharARBArray)
def glGetInfoLogARB(obj,maxLength,length,infoLog):pass
@_f
@_p.types(None,_cs.GLhandleARB,_cs.GLenum,arrays.GLfloatArray)
def glGetObjectParameterfvARB(obj,pname,params):pass
@_f
@_p.types(None,_cs.GLhandleARB,_cs.GLenum,arrays.GLintArray)
def glGetObjectParameterivARB(obj,pname,params):pass
@_f
@_p.types(None,_cs.GLhandleARB,_cs.GLsizei,arrays.GLsizeiArray,arrays.GLcharARBArray)
def glGetShaderSourceARB(obj,maxLength,length,source):pass
@_f
@_p.types(_cs.GLint,_cs.GLhandleARB,arrays.GLcharARBArray)
def glGetUniformLocationARB(programObj,name):pass
@_f
@_p.types(None,_cs.GLhandleARB,_cs.GLint,arrays.GLfloatArray)
def glGetUniformfvARB(programObj,location,params):pass
@_f
@_p.types(None,_cs.GLhandleARB,_cs.GLint,arrays.GLintArray)
def glGetUniformivARB(programObj,location,params):pass
@_f
@_p.types(None,_cs.GLhandleARB)
def glLinkProgramARB(programObj):pass
@_f
@_p.types(None,_cs.GLhandleARB,_cs.GLsizei,ctypes.POINTER( ctypes.POINTER( _cs.GLchar )),arrays.GLintArray)
def glShaderSourceARB(shaderObj,count,string,length):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLfloat)
def glUniform1fARB(location,v0):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,arrays.GLfloatArray)
def glUniform1fvARB(location,count,value):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint)
def glUniform1iARB(location,v0):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,arrays.GLintArray)
def glUniform1ivARB(location,count,value):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLfloat,_cs.GLfloat)
def glUniform2fARB(location,v0,v1):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,arrays.GLfloatArray)
def glUniform2fvARB(location,count,value):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLint)
def glUniform2iARB(location,v0,v1):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,arrays.GLintArray)
def glUniform2ivARB(location,count,value):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glUniform3fARB(location,v0,v1,v2):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,arrays.GLfloatArray)
def glUniform3fvARB(location,count,value):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint)
def glUniform3iARB(location,v0,v1,v2):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,arrays.GLintArray)
def glUniform3ivARB(location,count,value):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glUniform4fARB(location,v0,v1,v2,v3):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,arrays.GLfloatArray)
def glUniform4fvARB(location,count,value):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint)
def glUniform4iARB(location,v0,v1,v2,v3):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,arrays.GLintArray)
def glUniform4ivARB(location,count,value):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,_cs.GLboolean,arrays.GLfloatArray)
def glUniformMatrix2fvARB(location,count,transpose,value):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,_cs.GLboolean,arrays.GLfloatArray)
def glUniformMatrix3fvARB(location,count,transpose,value):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,_cs.GLboolean,arrays.GLfloatArray)
def glUniformMatrix4fvARB(location,count,transpose,value):pass
@_f
@_p.types(None,_cs.GLhandleARB)
def glUseProgramObjectARB(programObj):pass
@_f
@_p.types(None,_cs.GLhandleARB)
def glValidateProgramARB(programObj):pass



'''OpenGL extension NV.shader_thread_group

This module customises the behaviour of the 
OpenGL.raw.GL.NV.shader_thread_group to provide a more 
Python-friendly API

Overview (from the spec)
	
	Implementations of the OpenGL Shading Language may, but are not required 
	to, run multiple shader threads for a single stage as a SIMD thread group, 
	where individual execution threads are assigned to thread groups in an 
	undefined, implementation-dependent order.  This extension provides a set 
	of new features to the OpenGL Shading Language to query thread states and 
	to share data between fragments within a 2x2 pixel quad. 
	
	More specifically the following functionalities were added:
	
	*   New uniform variables and tokens to query the number of threads in a 
	    warp, the number of warps running on a SM and the number of SMs on the 
	    GPU.
	
	*   New shader inputs to query the thread id, the warp id and the SM id.
	
	*   New shader inputs to query if a fragment shader thread is a helper
	    thread.
	
	*   New shader built-in functions to query the state of a Boolean condition
	    over all threads in a thread group.
	
	*   New shader built-in functions to query which threads are active within
	    a thread group.        
	
	*   New fragment shader built-in functions to share data between fragments 
	    within a 2x2 pixel quad.
	
	Shaders using the new functionalities provided by this extension should 
	enable this functionality via the construct
	
	    #extension GL_NV_shader_thread_group : require     (or enable)
	
	This extension also specifies some modifications to the program assembly
	language to support the thread state query and thread data sharing
	functionalities.
	
	Note that in this extension specification warp and thread group have the
	same meaning.  A warp is a group of threads that get executed in lockstep.
	Each thread in a warp executes the same instruction of a program, but on
	different data.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/shader_thread_group.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.shader_thread_group import *
from OpenGL.raw.GL.NV.shader_thread_group import _EXTENSION_NAME

def glInitShaderThreadGroupNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_NV_framebuffer_multisample_coverage'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_NV_framebuffer_multisample_coverage',error_checker=_errors._error_checker)
GL_MAX_MULTISAMPLE_COVERAGE_MODES_NV=_C('GL_MAX_MULTISAMPLE_COVERAGE_MODES_NV',0x8E11)
GL_MULTISAMPLE_COVERAGE_MODES_NV=_C('GL_MULTISAMPLE_COVERAGE_MODES_NV',0x8E12)
GL_RENDERBUFFER_COLOR_SAMPLES_NV=_C('GL_RENDERBUFFER_COLOR_SAMPLES_NV',0x8E10)
GL_RENDERBUFFER_COVERAGE_SAMPLES_NV=_C('GL_RENDERBUFFER_COVERAGE_SAMPLES_NV',0x8CAB)
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,_cs.GLsizei,_cs.GLenum,_cs.GLsizei,_cs.GLsizei)
def glRenderbufferStorageMultisampleCoverageNV(target,coverageSamples,colorSamples,internalformat,width,height):pass
